/*
******************************************************************************
*
*                   Copyright (c) 2003-2004 HHP Inc.
*
*                        All Rights Reserved.
*
******************************************************************************
*
* $Revision: 1.1 $
* $Date: 2007/06/20 09:09:01EDT $
* $Author: MontoroJ $
*
*  File:        OemTriggerSound.h
*
*  Description: This file contains the function prototypes for functions that
*               an oem can supply to override the default trigger key (up arrow)
*               and beep sound which is normally PlaySound( "wave file" ).
*               The oem can choose to implement some or all of the functions.
*               The functions should work as follows:
*
*          DWORD OemForceConnectPort( void ) - This function should return the
*                               HHI_CONNECT_TYPE value of the port on which the
*                               imager can be found. (Note: HHI_CONNECT_TYPE
*                               name and actual port are related as follows:
*                               for HHI_COM1 == 0, HHI_COM8 == 7, etc...
*
*          DWORD OemForceBaudRate( bool *bAutoBaud ) - This function should return
*                               the HHI_BAUD_RATE value of the baud rate at which
*                               imager should be connected. HHI_BAUD_RATE values
*                               and names are the same. e.g. SERIAL_BAUD_115200
*                               has a value of 115200.
*
*          DWORD OemGetAppBehaviorFlags( void ) - This function should return
*                               the logical OR of any, all or none of the flags
*                               defined. These flags can modify specific behavior
*                               in the Demo Application.
*
*          bool  OemPlaySound( OemSound_t oemSound ) - This function should play
*                               whatever it wants to assign to the oem sound
*                               and return true. If it chooses not to implement
*                               a sound for the requested OemSound_t the it
*                               should return false so that the default sound
*                               for that OemSound_t will be played.
*          void  OemSetHostMsgHwnd( HWND hHostHwnd ) -  This function is called
*                               by the host to provide OEM functions with the
*                               host window handle. This can be used in a couple
*                               of ways:
*
*                               a) Send the a trigger message directly to the
*                                  host window. The message ID should be
*                                  WM_OEM_TRIGGER_MSG and should have the
*                                  following parameters:
*
*                                  message ID - WM_OEM_TRIGGER_MSG
*                                  WPARAM     - 1 (TRUE) for trigger down.
*                                             - 0 (FALSE) for trigger release.
*                                  LPARAM     - Trigger number (or 0)
*
*                               b) Use the window handle as part of registering
*                                  a hot key. OemCheckForTrigger() should then
*                                  be included. It will be called by the host
*                                  whenever it receives a message.  It's up to
*                                  OemCheckForTrigger() to see if it's the
*                                  registered message and if so report back the
*                                  trigger state in the pointer param.
*
*          void  OemIgnoreDefaultTrigger( void ) - This function should return
*                               true if the application should only respond to
*                               the WM_OEM_TRIGGER_MSG or false if it should
*                               respond to both the OEM mesage and the default
*                               trigger (usually the up arrow).
*
*          void  OemSetTriggerCallback( HOSTTRIGGERCALLBACK ) - Gives oem pointer
*                               to trigger callback function.
*
*          void  OemCheckForTrigger( MSG *lpMsg,bool *bEnabled,int *nTrigNum ) -
*                               This function should check the windows message
*                               for whatever the oem is using as a trigger
*                               notification. If it's the trigger message, the
*                               function should return true, otherwise it should
*                               return false. If true, the function must at least
*                               set bEnabled as follows: true if triggered, false
*                               if released. It can optionally return the trigger
*                               number if available or 0.
*
*               The Dll should be named OemTriggerSound.dll & be located in the
*               default library search path.  It will be loaded automatically
*               by the application.
*
*  Rev. Date    By     Revision Notes
*  ----------   ---    ----------------
*  04/01/2004   JCM    Original Release
*
******************************************************************************
*/

#ifndef _OEMTRIGGERANDSOUND_H   // Include Once
    #define _OEMTRIGGERANDSOUND_H
    // Include TCHAR header if windows.
#ifndef _WIN32_WCE
    #include <TChar.h>
#endif

    // Trigger message ID.
    #define WM_OEM_TRIGGER_MSG          (WM_USER+1453)
    // Sound types
    typedef enum
    {
        OEM_SOUND_SUCCESS=0,
        OEM_SOUND_ERROR,
        OEM_SOUND_SHORT_BEEP,
        OEM_SOUND_DEFAULT

    } OemSound_t;

#ifndef _WIN32_WCE
    #ifdef UNICODE
        // Function name definitions.
        #define OEMPLAYSOUNDNAME            "OemPlaySound"
        #define OEMSETHOSTMSGHWNDNAME       "OemSetHostMsgHwnd"
        #define OEMNODEFAULTTRIGGERNAME     "OemNoDefaultTrigger"
        #define OEMSETTRIGGERCALLBACKNAME   "OemSetTriggerCallback"
        #define OEMCHECKFORTRIGGERNAME      "OemCheckForTrigger"
        #define OEMGETAPPBEHAVIORFLAGSNAME  "OemGetAppBehaviorFlags"
        #define OEMFORCECONNECTPORTNAME     "OemForceConnectPort"
        #define OEMFORCEBAUDRATENAME        "OemForceBaudRate"
    #else
        // Function name definitions.
        #define OEMPLAYSOUNDNAME            _T("OemPlaySound")
        #define OEMSETHOSTMSGHWNDNAME       _T("OemSetHostMsgHwnd")
        #define OEMNODEFAULTTRIGGERNAME     _T("OemNoDefaultTrigger")
        #define OEMSETTRIGGERCALLBACKNAME   _T("OemSetTriggerCallback")
        #define OEMCHECKFORTRIGGERNAME      _T("OemCheckForTrigger")
        #define OEMGETAPPBEHAVIORFLAGSNAME  _T("OemGetAppBehaviorFlags")
        #define OEMFORCECONNECTPORTNAME     _T("OemForceConnectPort")
        #define OEMFORCEBAUDRATENAME        _T("OemForceBaudRate")
    #endif
#else
    // Function name definitions.
    #define OEMPLAYSOUNDNAME            _T("OemPlaySound")
    #define OEMSETHOSTMSGHWNDNAME       _T("OemSetHostMsgHwnd")
    #define OEMNODEFAULTTRIGGERNAME     _T("OemNoDefaultTrigger")
    #define OEMSETTRIGGERCALLBACKNAME   _T("OemSetTriggerCallback")
    #define OEMCHECKFORTRIGGERNAME      _T("OemCheckForTrigger")
    #define OEMGETAPPBEHAVIORFLAGSNAME  _T("OemGetAppBehaviorFlags")
    #define OEMFORCECONNECTPORTNAME     _T("OemForceConnectPort")
    #define OEMFORCEBAUDRATENAME        _T("OemForceBaudRate")
#endif
    // DLL Name
    #define OEMTRIGGERSOUNDNAME         _T("OemTriggerSound.dll")
    // Application Behavior Flags (can be or'ed together)
    #define OEM_NO_CHANGE_BAUD_RATE     0x00000001  // Omit Change Baud Rate menu item
    #define OEM_SINGLE_TRIGGER_IMAGE    0x00000002  // Image mode first trigger takes image (no aimers).
    #define OEM_NO_IMAGE_PROGRESS_BAR   0x00000004  // No progress bar during image transfer.
    #define OEM_NO_WAIT_CURSOR          0x00000008  // No wait cursor during capture
    #define OEM_NO_POWER_MANAGEMENT     0x00000010  // Omit Power Management menu item.
    #define OEM_NO_TRIGGER_HOLD         0x00000020  // Trigger gives immediate trigger up after trigger
                                                    // down even if user still pressing trigger.
    #define OEM_NO_UPGRADE_FIRMWARE     0x00000040  // Don't give upgrade firmware option.

#ifdef __cplusplus
    extern "C"
    {
#endif  /* __cplusplus */

        // Prototype for host trigger callback function
        typedef void (*HOSTTRIGGERCALLBACK)( bool,int ); // Tell Host trigger is pressed (true) or released (false)
        // *** Function prototypes ***
        // Beeper function
        __declspec( dllexport ) bool  OemPlaySound( OemSound_t nSoundMode );
        // Trigger functions.
        __declspec( dllexport ) void  OemSetHostMsgHwnd( HWND hHostWnd );
        __declspec( dllexport ) bool  OemNoDefaultTrigger( void );
        __declspec( dllexport ) bool  OemCheckForTrigger( MSG *lpMsg,bool *bEnabled,int *nTrigNum );
        __declspec( dllexport ) void  OemSetTriggerCallback( HOSTTRIGGERCALLBACK );
        // General App behavior modifiers
        __declspec( dllexport ) DWORD OemGetAppBehaviorFlags( void );
        __declspec( dllexport ) DWORD OemForceConnectPort( void );
        __declspec( dllexport ) DWORD OemForceBaudRate( bool *bAutoBaud );
        // LoadLibrary function pointer typedefs
        typedef bool  (*OEMPLAYSOUND)( OemSound_t );        // Oem Supplied Beeper Sounds
        typedef void  (*OEMSETHOSTMSGHWND)( HWND );         // HWND from host to which trigger mesage sent.
        typedef void  (*OEMSETTRIGGERCALLBACK)( HOSTTRIGGERCALLBACK ); // Host's trigger callback.
        typedef bool  (*OEMNODEFAULTTRIGGER)( void );       // Also respond to default trigger (up arrow)?.
        typedef bool  (*OEMCHECKFORTRIGGER)( MSG *,bool *,int * );// Also respond to default trigger (up arrow)?.
        typedef DWORD (*OEMGETAPPBEHAVIORFLAGS)( void );    // Application behavior flags.
        typedef DWORD (*OEMFORCECONNECTPORT)( void );       // Comm port for connect.
        typedef DWORD (*OEMFORCEBAUDRATE)( bool * );        // Baud Rate & whether to autobaud.

#ifdef __cplusplus
    }
#endif  /* __cplusplus */

#endif // _OEMTRIGGERANDSOUND
