/*
******************************************************************************
*
*               Copyright (c) 2002-2007 Hand Held Products Inc.
*
*                        All Rights Reserved.
*
******************************************************************************
*
* $RCSfile: hhiImgrCfg.h $
* $Revision: 1.10 $
* $Date: 2008/05/21 16:26:25EDT $
* $Author: MontoroJ $
*
*  File:        hhiImgrCfg.h
*
*  Description: Contains the Imager configuration structures for image capture
*               and all other imager related configuration items except decoder.
*
*  Rev. Date    By    Revision Notes
*  ----------   ---   ----------------
*  07/24/2002   JCM   Original Release
*  11/14/2002   JCM   Removed dependency on ENGINE_API
*  09/08/2004   JCM   Changed Sequence Mode structure and mask names.
*  07/19/2005   JCM   Added Decoder and Scan Driver versions to version struct.
*
******************************************************************************
*/

#ifndef HHIIMGRCFG_H

    #define HHIIMGRCFG_H

    //-----------------------------------------------------------------------------
    // Image formats
    //-----------------------------------------------------------------------------

    typedef enum
    {
        FF_RAW_BINARY = 0,
        FF_RAW_GRAY,
        FF_TIFF_BINARY,
        FF_TIFF_BINARY_PACKBITS,
        FF_TIFF_GRAY,
        FF_JPEG_GRAY,
        FF_BMP_GRAY

    } FileFormat_t;
    // DWORD -1 (bad value)
    #define BAD_DWORD_VALUE ((DWORD)-1)
    // Universal Mask
    #define ALL_MASK        0xffffffff
    //-----------------------------------------------------------------------------
    // Compression mode formats
    //-----------------------------------------------------------------------------
    typedef enum
    {
        COMPRESSION_NONE=0,
        COMPRESSION_LOSSLESS,
        COMPRESSION_LOSSY

    } Compression_t, HHI_COMPRESSION_MODE, *PHHI_COMPRESSION_MODE;
    // Capture Illumination Duty Cycle
    typedef enum
    {
        HHI_DUTY_CYCLE_OFF=0,
        HHI_DUTY_CYCLE_ON

    } HHI_DUTY_CYCLE;

    #define HHI_CAPTURE_ALWAYS_OFF      HHI_DUTY_CYCLE_OFF
    #define HHI_CAPTURE_ALWAYS_ON       HHI_DUTY_CYCLE_ON

    // Auto Exposure type
    typedef enum
    {
        HHI_AUTOEXPOSURE_BARCODE=0,
        HHI_AUTOEXPOSURE_PHOTO,
        HHI_AUTOEXPOSURE_MANUAL

    } HHI_AUTOEXPOSURE;
    #define HHI_AUTOEXPOSURE_NONE       HHI_AUTOEXPOSURE_MANUAL
    #define HHI_AUTOEXPOSURE_FIXED      HHI_AUTOEXPOSURE_NONE
    // Min and Max manual exposure
    #define MAX_MANUAL_EXPOSURE         7874
    #define MIN_MANUAL_EXPOSURE         1
    // Gain Values
    typedef enum
    {
        HHI_GAIN_1x=1,
        HHI_GAIN_2x,
        HHI_GAIN_4x=4

    } HHI_GAIN;
    // Frame rate enum
    typedef enum
    {
        HHI_1_FRAMES_PER_SEC=1,
        HHI_2_FRAMES_PER_SEC,
        HHI_3_FRAMES_PER_SEC,
        HHI_4_FRAMES_PER_SEC,
        HHI_5_FRAMES_PER_SEC,
        HHI_6_FRAMES_PER_SEC,
        HHI_10_FRAMES_PER_SEC=10,
        HHI_12_FRAMES_PER_SEC=12,
        HHI_15_FRAMES_PER_SEC=15,
        HHI_20_FRAMES_PER_SEC=20,
        HHI_30_FRAMES_PER_SEC=30

    } HHI_FRAME_RATE;
    // Image Acquisition bit masks
    #define WHITE_VALUE_MASK             0x00001
    #define WHITE_WINDOW_MASK            0x00002
    #define MAX_CAPTURE_RETRIES_MASK     0x00004
    #define ILLUMINATION_DUTY_CYCLE_MASK 0x00008
    #define LIGHTS_DUTY_CYCLE_MASK       0x00008
    #define AIMER_DUTY_CYCLE_MASK        0x00010
    #define FIXED_GAIN_MASK              0x00020
    #define FIXED_EXPOSURE_MASK          0x00040
    #define FRAME_RATE_MASK              0x00080
    #define AUTOEXPOSURE_MODE_MASK       0x00100
    #define IMAGE_CAPTURE_MODE_MASK      0x00100
    #define WAIT_FOR_TRIGGER_MASK        0x00200
    #define PREVIEW_MODE_IMAGE_MASK      0x00400
    #define VGA_COMPATIBLE_IMAGE_MASK    0x00800
    #define TARGET_PERCENTILE_MASK       0x01000
    #define BEEP_ON_CAPTURE_MASK         0x02000
    #define CAPTURE_MASK_CONFIG_ALL      0x039ff
    #define CAPTURE_MASK_FIXED_AGC       0x03980
    #define CAPTURE_MASK_ALL             0x03fff
    // Image Acquisition structure
    typedef struct _tagHHI_IMAGE_ACQUISITION
    {
        DWORD            dwStructSize;
        DWORD            dwMask;
        DWORD            dwWhiteValue;          // 0 - 255
        DWORD            dwWhiteWindow;         // 0 - 255
        DWORD            dwMaxNumExposures;     // 9
        HHI_DUTY_CYCLE   illuminatCycle;
        HHI_DUTY_CYCLE   aimerCycle;
        HHI_GAIN         fixedGain;
        DWORD            dwFixedExposure;       // 0 - 7874
        HHI_FRAME_RATE   frameRate;
        HHI_AUTOEXPOSURE captureMode;
        BOOL             bVgaCompatibleImage;       // 640x480 Max Image Size.
        // Capture time only, not real config items
        BOOL             bWaitForTrigger;
        BOOL             bPreviewImage;
        // Back to read config items.
        DWORD            dwTargetPercentile;    // 0 - 100
        BOOL             bBeepOnCapture;

    } HHI_IMAGE_ACQUISITION, *PHHI_IMAGE_ACQUISITION;
    // Image Transfer bit masks
    #define BITS_PER_PIXEL_MASK         0x00001
    #define SUBSAMPLE_VALUE             0x00002
    #define SUBSAMPLE_VALUE_MASK        0x00002
    #define BOUNDING_RECTANGLE_MASK     0x00004
    #define COMPRESSION_MODE_MASK       0x00008
    #define HISTOGRAM_STRETCH_MASK      0x00010
    #define COMPRESSION_FACTOR_MASK     0x00020
    #define EDGE_ENHANCEMENT_MASK       0x00100
    #define GAMMA_CORRECTION_MASK       0x00200
    #define TEXT_ENHANCEMENT_MASK       0x00400
    #define INFINITY_FILTER_MASK        0x00800
    #define FLIP_IMAGE_MASK             0x01000
    #define NOISE_FILTER_MASK           0x02000
    #define UNSHARPEN_BRIGHTEN_MASK     0x04000
    #define ADAPTIVE_TEXT_FILTER_MASK   0x08000
    #define TRANSFER_UPDATE_HWND        0x00040
    #define TRANSFER_UPDATE_DWORD       0x00080
    #define TRANSFER_MASK_ALL           0x0ffff
    #define TRANSFER_MASK_ALL_NO_NOTIFY 0x0ff3f
    // Value ranges
    #define MIN_SUBSAMPLE               1
    #define MAX_SUBSAMPLE               10
    #define MIN_COMPRESSION_FACTOR      0
    #define MAX_COMPRESSION_FACTOR      100
    #define MIN_EDGE_ENHANCEMENT        0
    #define MAX_EDGE_ENHANCEMENT        23
    #define MIN_GAMMA_CORRECTION        0
    #define MAX_GAMMA_CORRECTION        1000
    #define MIN_TEXT_ENHANCEMENT        0
    #define MAX_TEXT_ENHANCEMENT        255
    // Image Transfer structure
    typedef struct _tagHHI_IMAGE_TRANSFER
    {
        DWORD           dwStructSize;
        DWORD           dwMask;
        DWORD           dwBitsPerPixel;     // 1,8
        DWORD           dwSubSample;        // 1-10
        RECT            boundingRect;       // (0,0)-(max x,max y) see image capabilities.
        BOOL            bHistogramStretch;  // TRUE,FALSE
        Compression_t   compressionMode;    // see Compression_t.
        DWORD           dwCompressionFactor;// 0-100
        DWORD           dwEdgeEhancement;   // 0-23
        DWORD           dwGammaCorrection;  // 0-1000
        DWORD           dwTextEnhancement;  // 0-255
        BOOL            bInfinityFilter;    // TRUE,FALSE
        BOOL            bFlipImage;         // TRUE,FALSE
        BOOL            bNoiseFilter;       // TRUE,FALSE
        // Transfer time only, not stored in imager.
        HWND            hTransferNotifyHwnd;
        PDWORD          pdwTransferPercent;
        // New items
        BOOL            bUnsharpenBrighten; // TRUE,FALSE
        BOOL            bAdaptiveTextFilter;// TRUE,FALSE

    } HHI_IMAGE_TRANSFER, *PHHI_IMAGE_TRANSFER;
    // Image information structure
    typedef struct _tagHHI_IMAGE
    {
        DWORD           dwStructSize;
        PBYTE           puchBuffer;         // Buffer for image
        LONG            nBufferSize;        // Size of buffer in bytes
        FileFormat_t    fileFormat;         // Format for returned data
        DWORD           dwJpegQFactor;      // JPEG Quality Factor
        LONG            nBytesReturned;     // Number of bytes returned.
        SIZE            imgSize;            // Size of image returned.
		LONG	        nGain;              // Gain value used to capture this image
		LONG	        nExposureTime;      // Exposure time used to capture this image

    } HHI_IMAGE, *PHHI_IMAGE;
    //------------------------------------------------------------------
    //  Data structure that holds the decoded barcode message.
    //------------------------------------------------------------------
    #define MAX_MESAGE_LENGTH                       4096
    typedef struct _tagHHI_DECODE_MSG
    {
        DWORD   dwStructSize;                       // Size of decode structure.
        TCHAR   pchMessage[ MAX_MESAGE_LENGTH ];    // decoded message data
        TCHAR   chCodeID;                           // AIM Id of symbology
        TCHAR   chSymLetter;                        // HHP Id of symbology
        TCHAR   chSymModifier;                      // Modifier characters.
        DWORD   nLength;                            // length of the decoded message

    } HHI_DECODE_MSG, DecodeMsg_t, *PHHI_DECODE_MSG;
	// Raw decode structure
    typedef struct _tagHHI_RAW_DECODE_MSG
    {
        DWORD   dwStructSize;                       // Size of decode structure.
        BYTE    pchMessage[ MAX_MESAGE_LENGTH ];    // decoded message data
        BYTE    chCodeID;                           // AIM Id of symbology
        BYTE    chSymLetter;                        // HHP Id of symbology
        BYTE    chSymModifier;                      // Modifier characters.
        DWORD   nLength;                            // length of the decoded message

    } HHI_RAW_DECODE_MSG, RawDecodeMsg_t, *PHHI_RAW_DECODE_MSG;

	// Beeper Volume enum
    typedef enum
    {
        BEEP_OFF=0,
        BEEP_LOW=1,
        BEEP_MEDIUM=2,
        BEEP_HIGH=3

    } HHI_BEEPER_VOLUME;
    #define BEEPER_VOLUME               HHI_BEEPER_VOLUME
    // Beeper Set Bitmask
    #define BPMASK_ON_DECODE            0x00001
    #define BPMASK_BEEPS_ON_DECODE      0x00001
    #define BPMASK_SHORT_BEEP           0x00002
    #define BPMASK_MENU_CMD_BEEP        0x00004
    #define BPMASK_BEEP_VOLUME          0x00008
    #define BPMASK_GOOD_READ_FREQUENCY  0x00010
    #define BPMASK_BEEPS_ON_ERROR       0x00020
    #define BPMASK_ERROR_FREQUENCY      0x00040
    #define BPMASK_ALL                  0x0007f
    // Beeper structure
    typedef struct _tagHHI_BEEPER
    {
        DWORD             dwStructSize;
        DWORD             dwMask;
        BOOL              bShortBeep;           // Short duration beeps?
        BOOL              bMenuCmdBeep;
        HHI_BEEPER_VOLUME beepVolume;           // Default is BEEP_HIGH
        DWORD             dwBeepsOnDecode;      // Number of beeps on decode.
        DWORD             dwGoodReadFreq;       // Default is 3250 Hz
        DWORD             dwBeepsOnError;       // Number of beeps on error.
        DWORD             dwErrorFreq;          // Default is 800

    } HHI_BEEPER, *PHHI_BEEPER;

    // Trigger Timeout Range
    #define MIN_TRIGGER_TIMEOUT_VAL     0       // Infinite
    #define MAX_TRIGGER_TIMEOUT_VAL     300000  // 5 Minutes.
    // Trigger stucture masks
    #define TRGMASK_TRIG_MODE           0x00001
    #define TRGMASK_TIMEOUT             0x00002
    #define TRGMASK_ALL                 0x00003

    // Trigger Modes type
    typedef enum
	{
		HHI_MANUAL_SERIAL = 0,      // Manual trigger no low power mode.
        HHI_UNUSED,                 // Unused
		HHI_MANUAL_LOW_POWER,       // Manual trigger with low power mode on timeouts
		HHI_PRESENTATION,           // Looks for objects which can be barcodes and triggers if found
		HHI_SCANSTAND,              // Triggers if scanstand barcode not detected
        HHI_HOST_NOTIFY,            // Unused
        HHI_SNAP_AND_SHIP,          // Imager Ships image on trigger.
        HHI_UNUSED_1,               // Unused
        HHI_PRESENTATION_4600R

	} HHI_TRIG_MODES;

	 // Triggering control
    typedef struct _tagHHI_TRIGGER
    {
        DWORD			dwStructSize;
        DWORD			dwMask;
        HHI_TRIG_MODES	TriggerMode;
        DWORD           dwTriggerTimeout;   // 0->300000 (milliseconds)

    } HHI_TRIGGER, *PHHI_TRIGGER;

    #define MAX_SEQ_BARCODES            12
    #define MAX_NUM_START_CHARS         32
    #define SEQ_ALL_LENGTH              9999
    // Sequence stucture masks
    #define SEQMASK_MODE                0x00001 // sequenceMode
    #define SEQMASK_BARCODES            0x00002 // dwNumBarCodes & seqBarCodes[]
    #define SEQMASK_ALL                 0x00003 // Everything.

    // Sequence Modes type
    typedef enum
    {
        HHI_SEQ_DISABLED = 0,
        HHI_SEQ_ENABLED,
        HHI_SEQ_REQUIRED

    } HHI_SEQ_MODES;

    // Sequence mode barcode descriptor
    typedef struct _tagSeqBarCode_t
    {
        LONG    nSymId;         // Symbology Identifier SYM_xxxx
        LONG    nLength;        // Match length or 9999 to match any length.
        TCHAR   tcStartChars[ MAX_NUM_START_CHARS+1 ]; // Match string (from start)

    } SeqBarCode_t, *PSeqBarCode_t;
    // Sequence Mode control
    typedef struct _tagHHI_SEQUENCE_MODE
    {
        DWORD         dwStructSize;
        DWORD         dwMask;
        HHI_SEQ_MODES sequenceMode; // Disabled/Enabled/Enabled and Required.
        DWORD         dwNumBarCodes;// This MUST be sent if sending seqBarCodes.
        SeqBarCode_t  seqBarCodes[ MAX_SEQ_BARCODES ];

    } HHI_SEQUENCE_MODE, *PHHI_SEQUENCE_MODE;
    // Decoder mode enum
    typedef enum
    {
        DECODE_METHOD_STANDARD=0,               //Normal decode mode (default)
        DECODE_METHOD_QUICK_OMNI,               //Fast omni directional decoder
        DECODE_METHOD_NONOMNI_ALD,              //Non omni Advanced Linear Decoder
        DECODE_METHOD_OMNI_LINEAR               //Omni directional linear decoder

    } DECODE_METHOD, HHI_DECODE_METHOD;
    // Decoder mode enum
    typedef enum
    {
        SECONDARY_LEDS=0,                       // Secondary Color (Green/White/whatever) if supported
        PRIMARY_LEDS                            // Default/Primary Illumination color (usually red)

    } ILLUM_LED_COLOR, HHI_ILLUM_LED_COLOR;
    // Min/Max for delays
    #define MIN_CODE_DELAY              10
    #define MAX_CONCAT_DELAY            1000
	#define MAX_COMPOSITE_DELAY         1000
	#define MAX_ADDENDA_DELAY           500
    // Decode method stucture masks
    #define DCMASK_MAX_MESAGE_LENGTH    0x00001
    #define DCMASK_DECODE_MULTIPLE      0x00002
    #define DCMASK_USE_AIMERS           0x00004
    #define DCMASK_PRINT_WEIGHT         0x00008
    #define DCMASK_DECODE_METHOD        0x00010
    #define DCMASK_CENTER_ENABLE        0x00020
    #define DCMASK_CENTER_WINDOW        0x00040
    #define DCMASK_ILLUMINAT_LED_COLOR  0x00080
    #define DCMASK_UPC_ADDENDA_DELAY    0x00100
    #define DCMASK_COMPOSITE_DELAY      0x00200
    #define DCMASK_CONCATENATE_DELAY    0x00400
    #define DCMASK_ALL                  0x007ff
    // Decoder functionality settings.
    typedef struct _tagHHI_DECODER_CONFIG
    {
        DWORD               dwStructSize;        // Size of HHI_DECODER_CONFIG.
        DWORD               dwMask;              // Expression mask
        DWORD               dwMaxMsgSize;        // Maximum size of an imager message
        BOOL                bDecodeMultiple;     // Shotgun mode.
        BOOL                bUseAimers;          // Turn aimers on inbetween decode attempts.
        DWORD               dwPrintWeight;       // 1->7
        HHI_DECODE_METHOD   decodeMethod;        // Method of decoding used by decoder
        BOOL                bCenterDecodeEnable; // Does symbol have to intersect center decode window to be valid.
        RECT                centerWindow;        // Bounding coords or window that decoded symbol must intersect
        HHI_ILLUM_LED_COLOR illumLedColor;       // Illumination LED color to use.
        DWORD               dwUpcAddendaDelay;   // 10->500  Delay before reading UPC if expecting addenda.
        DWORD               dwCompositeDelay;    // 10->1000 Delay before reading code if expecting composite.
        DWORD               dwConcatenateDelay;  // 10->1000 Delay to wait before reading code if expecting concatenated code.

    } HHI_DECODER_CONFIG, *PHHI_DECODER_CONFIG;

	// Aimer Modes
    typedef enum
    {
        AIMER_MODE_ALWAYS_OFF=0,             // No aimer LED's.
        AIMER_MODE_ILLUM_AND_AIM,            // Aimer LED's and Illumination LED's on simultaneously.
        AIMER_MODE_ALWAYS_ON                 // Aimer LED's always on.

    } HHI_AIMER_MODES;

	// System (MPU) clock speeds enum
    typedef enum
    {
        POWER_SYS_SPEED_96MHZ=0,
        POWER_SYS_SPEED_48MHZ=1,
        POWER_SYS_SPEED_32MHZ=2

    } HHI_SYS_SPEED;
    // Power setting item masks
    #define PWRMASK_TRIGGER_MODE             0x00001	//TRGMOD
    #define PWRMASK_SERIAL_TRIGGER_TIMEOUT   0x00002	//TRGSTO
    #define PWRMASK_STOP_MODE_TIMEOUT        0x00004    //TRGLPT
    #define PWRMASK_ILLUM_LED_INTENSITY      0x00008	//PWRLDC
    #define PWRMASK_SYS_SPEED                0x00010	//PWRSPD
    #define PWRMASK_AIMER_MODE               0x00020	//SCNAIM
    #define PWRMASK_AIMER_DURATION           0x00040	//SCNADR
    #define PWRMASK_AIMER_DELAY              0x00080	//SCNDLY
    #define PWRMASK_IMAGER_IDLE_TIMEOUT      0x00100	//SDRTIM
    #define PWRMASK_SLEEP_MODE_TIMEOUT       0x00200	//232LPT
    #define PWRMASK_SLEEP_MODE_TIMOUT        0x00200    //232LPT
    #define PWRMASK_POWER_OFF_HANDLE         0x00400
    #define PWRMASK_POWER_OFF_HWND           0x00800
    #define PWRMASK_AUTO_AIMER_TIMEOUT       0x01000    //SCNAAM
    #define PWRMASK_ALL                      0x01FFF
    // Engineering Type Names.
    #define PWRMASK_SLEEP_MODE_TIMOUT        0x00200	//232LPT
    #define PWRMASK_LOW_POWER_TIMOUT         0x00004	//TRGLPT
    #define PWRMASK_LOW_POWER_TIMEOUT        0x00004	//TRGLPT
    #define PWRMASK_RS232_LOW_POWER_TIMOUT   0x00200	//232LPT
	// Matrix Products Power management structure
    typedef struct _tagHHI_POWER_SETTINGS
    {
        DWORD           dwStructSize;
        DWORD           dwMask;
        HHI_TRIG_MODES	TriggerMode;            // Trigger mode (same as per trigger struct)
        DWORD           dwTriggerTimeout;       // 0 -> 300000 (milliseconds)
        DWORD           dwLowPowerTimeout;      // 0 -> 300    (seconds)
        DWORD           dwLEDIntensityPercent;  // 0 -> 100%
        HHI_SYS_SPEED   systemClockSpeed;       // Clock speed for reset of system (except RS232)
		HHI_AIMER_MODES AimerMode;              // Aimer Mode
		DWORD           dwAimerDuration;        // 0 -> 240000 (milliseconds)
		DWORD           dwAimerDelay;           // 0 -> 4000   (milliseconds)
        DWORD           dwAutoAimerTimeout;     // 0 -> 30000  (milliseconds)
		DWORD           dwImagerIdleTimeout;    // 0 -> 999999 (milliseconds)
        DWORD           dwRS232LowPwrTimeout;   // 0 -> 300    (seconds)RS232 inactivity timeout used to enter sleep mode.
        // These are used to notify on suspend (WinCE Suspend)
        HANDLE          hPowerOffHandle;
        HWND            hPowerOffHwnd;

    } HHI_POWER_SETTINGS, *PHHI_POWER_SETTINGS;

    // Engine Id values from imager.
    typedef enum
    {
    	TYPE_NONE   =0,  // No imager hardware
	    TYPE_IT4200 =1,
    	TYPE_IT4000 =5,
	    TYPE_IT4100 =6,
    	TYPE_IT4300 =7,
	    TYPE_IT5X00VGA = 10,
    	TYPE_IT5X00VGA_PSOC = 11,
	    TYPE_IT5X00 = 12,
    	TYPE_IT5X00_PSOC = 13

    } EngineType_t, *PEngineType_t;
	// Versions setting item masks
    #define VERMASK_SDK_API                 0x00001
    #define VERMASK_IMAGER_FIRMWARE         0x00002
    #define VERMASK_IMAGER_PART_NUM         0x00004
    #define VERMASK_IMAGER_BOOT_CODE        0x00008
    #define VERMASK_IMAGER_DEVICE_TYPE      0x00010
    #define VERMASK_MANUFACTURERS_ID        0x00020
    #define VERMASK_DECODER_REV             0x00040
    #define VERMASK_SCAN_DRIVER_REV         0x00080
    #define VERMASK_ALL                     0x000ff
    // Revision information
    #define MAX_VERSION_STRING_LEN          128
    #define MAX_DEVICE_TYPE_STRING_LEN      64
    #define MAX_MANUFACTURERS_ID_LEN        16
    typedef struct _tagHHI_VERSION_INFO
    {
        DWORD   dwStructSize;
        DWORD   dwMask;
        TCHAR   tcAPIRev[ MAX_VERSION_STRING_LEN ];             // SDK API version string
        TCHAR   tcFirmwareRev[ MAX_VERSION_STRING_LEN ];        // Imager firmware version
        TCHAR   tcFirmwarePartNumber[ MAX_VERSION_STRING_LEN ]; // Engine PartNumber.
        TCHAR   tcBootCodeRev[ MAX_VERSION_STRING_LEN ];        // Imager boot code version.
        TCHAR   tcDeviceType[ MAX_DEVICE_TYPE_STRING_LEN ];     // Imager device string.
        TCHAR   tcManufacturersId[ MAX_MANUFACTURERS_ID_LEN ];  // Engine Report string.
        TCHAR   tcDecoderRev[ MAX_VERSION_STRING_LEN ];         // Decoder Revision
        TCHAR   tcScanDriverRev[ MAX_VERSION_STRING_LEN ];      // Scan Driver Revision

    } HHI_VERSION_INFO, *PHHI_VERSION_INFO;
    // Defines for Engine Information Structure
    #define MAX_SHORT_VERSION_LEN           32
    #define MAX_SERIAL_NUMBER_LEN           16
    #define MAX_CHECKSUM_LEN                8
    #define ENGINE_ID_DIGITS                4
    // Engine Information Structure (5000K engine with PSOC only)
    typedef struct _tagHHI_ENGINE_INFO
    {
        DWORD   dwStructSize;                                   // Structure size
        TCHAR   tcEngId[ ENGINE_ID_DIGITS ];                    // 4 digit ASCII Hex.
        TCHAR   tcHHPSerialNumber[ MAX_SERIAL_NUMBER_LEN ];     // ASCII Decimal
        TCHAR   tcCustomSerialNumber[ MAX_SERIAL_NUMBER_LEN ];  // ASCII Decimal
        LONG    nAimerX;                                        // Aimer X
        LONG    nAimerY;                                        // Aimer Y
        LONG    nLaserPower;                                    // Laser power in mW
        TCHAR   tcFirmwareChecksum[ MAX_CHECKSUM_LEN ];         // Firmware Checksum (ASCII Decimal)
        TCHAR   tcFirmwareRev[ MAX_SHORT_VERSION_LEN ];         // Firmware Revision Number.Number
        LONG    nLedCtrlMode;                                   // How LEDs are controled.
        LONG    nLedClr;                                        // LED color (Red or Green LEDs)
        LONG    nPwmFreq;                                       // PWM base frequence.
        LONG    nRedLedCurrent;                                 // Red LED current (mA).
        LONG    nRedLedMaxCurrent;                              // Red LED max current (mA).
        LONG    nGreenLedCurrent;                               // Green LED current (mA).
        LONG    nGreenLedMaxCurrent;                            // Green LED max current (mA).
        LONG    nAimerCurrent;                                  // Aimer current (mA).
        LONG    nAimerMaxCurrent;                               // Aimer max current (mA).
        LONG    nPixelClockFreq;                                // Pixel clock frequency (MHz)
        TCHAR   tcRegisterChecksum[ MAX_CHECKSUM_LEN ];         // Register Checksum.

    } HHI_ENGINE_INFO, *PHHI_ENGINE_INFO;
    // HHI_CONFIG Read\Write configuration item settings masks
    typedef enum
    {
        BEEPER_CONFIG=0,
        TRIGGER_CONFIG,
        DECODER_CONFIG,
        POWER_CONFIG,
        VERSION_INFO,
        SYMBOLOGY_CONFIG,
        SERIAL_PORT_CONFIG,
        IMAGE_ACQUISITION,
        IMAGE_TRANSFER,
        SEQUENCE_CONFIG,
        ALL_CONFIG

    } ConfigItems_t;
//    #define POWER_SETTINGS    POWER_CONFIG
    // Big mother of them all configuration structure.
    typedef struct _tagHHI_CONFIG
    {
        DWORD                 dwStructSize;
        HHI_BEEPER            beeperCfg;
        HHI_TRIGGER           triggerCfg;
        HHI_DECODER_CONFIG    decoderCfg;
        HHI_POWER_SETTINGS    powerCfg;
        HHI_VERSION_INFO      versionInfo;
        HHI_SYM_CONFIG        symbolCfg;
        HHI_IMAGE_ACQUISITION imgAcqu;
        HHI_IMAGE_TRANSFER    imgTrans;
        HHI_SEQUENCE_MODE     sequenceCfg;
#ifdef ADD_PREFIX_SUFFIX_DATA_FORMATTER
        HHI_DATA_EDITING      dataEditCfg;
#endif

    } HHI_CONFIG, *PHHI_CONFIG;

#endif

// $Log: hhiImgrCfg.h  $
// Revision 1.10 2008/05/21 16:26:25EDT MontoroJ 
// - Removed all references to data formatting.
// Revision 1.9 2008/01/25 10:17:39EST MontoroJ 
// - Reverting accidental check in of multiple connect versions of these files into the single
//   connect version of the SDK
// Revision 1.7 2007/08/23 10:19:04EDT MontoroJ
// - Added 4600R presentation mode to trigger modes. (trig mode 8)
// Revision 1.6 2007/08/14 09:14:10EDT MontoroJ
// - Added more beeper support.
// Revision 1.5 2007/07/31 11:49:00EDT MontoroJ
// - Changed FF_BINARY_RAW back to FF_RAW_BINARY.  What was I thinking!??!
// Revision 1.4 2007/07/31 11:16:50EDT MontoroJ
// - Modified HHI_BEEPER structure:
//     - Renamed bBeepOnDecode --> dwBeepsOnDecode
//     - Added dwBeepsOnError
//     - Added dwGoodReadFreq
//     - Added dwErrorFreq
// Revision 1.3 2007/07/18 12:23:56EDT MontoroJ
// - Cleaned up some of the naming convention issues with some of the structures and masks.
// Revision 1.2 2007/06/21 12:51:44EDT MontoroJ
// - Removed the nCaptureFrames, nOverExposed and nUnderExposed members from the
//   HHI_IMAGE structure.  nGain and nExposure have been left in since the imager sends
//   items for these members (although it looks like the firmware does not actually fill them in).
// Revision 1.3 2007/03/29 13:17:28EST MontoroJ
// - Added dwTargetPercentile to HHI_IMAGE_ACQUISITION structure.
// - Added bAdaptiveTextFilter to HHI_IMAGE_TRANSFER structure.
// Revision 1.2 2007/02/28 15:52:41EST MontoroJ
// - Updated the module header information (specifically the copyright)
// Revision 1.26 2005/11/07 10:03:59EST MontoroJ
// - Updated max value for the HHI_POWER_SETTINGS aimer delay to 4000 (4 seconds)
// Revision 1.25 2005/07/26 16:37:51EDT MontoroJ
// - Added Noise Filter option to HHI_IMAGE_TRANSFER
// - Added Decoder Revision and Scan Driver Revision to HHI_VERSION_INFO
// - Added Auto Aimer Timeout to HHI_POWER_SETTINGS.
// - Added UPC Addenda Delay, Composite Code Delay and Concatenate Code Delay to
//   HHI_DECODER_CONFIG.
// Revision 1.24 2005/06/27 15:06:04EDT MontoroJ
// - Added BOOL setting to the HHI_IMAGE_ACQUISITION structure for setting the VGA
//   compatible image mode for 5000VGA and MegaPixel imagers.
// Revision 1.23 2005/06/22 09:24:28EDT MontoroJ
// - Renamed GREEN_LEDS / RED_LEDS  SECONDAY_LEDS / PRIIMARY_LEDS
// Revision 1.22 2005/05/26 18:06:20EDT MontoroJ
// - Moved HHI_ENGINE_INFO structure from hhiEngineInfo to here.
// Revision 1.21 2005/05/11 09:01:39EDT MontoroJ
// - Modified Version Info structure and code to be backwardly compatible with last 4080 SDK.
// Revision 1.20 2005/05/04 16:13:41EDT MontoroJ
// - Added enums for IT5000 imagers (other than 5000 VGA)
// Revision 1.19 2005/04/05 15:12:23EDT MontoroJ
// - Added IT5X00 variant information to existing structures:
//     - Added illumination color to HHI_DECODER_CONFIG.
//     - Made the following changes to HHI_VERSION_INFO:
//         - Changed tcPartNumber to tcFirmwarePartNumber.
//         - Added tcManufacturersId for engine ID and Checksum.
// Revision 1.18 2005/01/26 13:04:52EST montoroj
// - Added ifdef around DataFormater in ConfigItems_t
// Revision 1.17 2004/12/17 11:50:06EST montoroj
// - Added structures which are currently defined out for data formatting.
// Revision 1.16 2004/09/16 10:10:12EDT montoroj
// - Removed HHI_SEQUENCE structure and replaced it with HHI_SEQUENCE_MODE structure.
//   The new structure allows the caller to specify barcodes by SYM_ID, length and matching'
//   string (from start only as per normal sequence mode) up to 12 barcodes instead of having
//   to build the sequence string required by the imager.
// Revision 1.15 2004/08/02 11:08:32EDT montoroj
// - Added min/max defines for exposure so developers know what they are.
// Revision 1.14 2004/06/17 11:28:45EDT montoroj
// - Added define of BEEPER_VOLUME which was renamed HHI_BEEPER_VOLUME in SDK
//   but since SDK and Examples have different SharedInclude directories, it was never put
//   into Examples version of code.  This allows people to use either header with either project.
// Revision 1.13 2004/05/11 15:57:56EDT montoroj
// - Modified Image Transfer Structure by adding:
//     dwEdgeEnhancement	- EDGE_ENHANCEMENT_MASK
//     dwGammaCorrection	- GAMMA_CORRECTION_MASK
//     dwTextEnhancement	- TEXT_ENHANCEMENT_MASK
//     bInfinityFilter	- INFINITY_FILTER_MASK
//     bFlipImage		- FLIP_IMAGE_MASK
// also added min and max for DWORD values.
// Revision 1.12 2004/05/05 11:59:50EDT montoroj
// - Renamed BEEPER_VOLUME to HHI_BEEPER_VOLUME
// - Added comments
// - Added sleep mask defines (overloaded names) that make sense.
// Revision 1.11 2004/04/13 14:34:27EDT montoroj
// - Changed comments that describe ranges of trigger and serial low power timeouts.
// Revision 1.10 2004/03/24 15:58:05EST montoroj
// - Added HHI_SNAP_AND_SHIP to HHI_TRIG_MODES Trigger modes enum
// - Added some duplicatenames for some of the power masks that might be easier for a
//   developer to understand.
// Revision 1.9 2003/12/02 13:35:28EST holzhaud
//
// Added Raw decode structure.
// Revision 1.8 2003/07/07 13:07:56EDT holzhaud
// Removed Low Power Imaging from the POWER SETTINGS struct.
// Revision 1.7 2003/06/30 23:28:15EDT holzhaud
// Fixed Clock Speed enum type... wrong values; also removed an unused power mask #define.
// Revision 1.6 2003/06/26 15:00:55EDT holzhaud
// minor change in TRIGMSK
// Revision 1.5 2003/06/26 11:37:17EDT holzhaud
// Changed Decode, Beeper, and Trigger structures and enum types because of
// modified/changed/deleted/included new 4080 menu commands.
// Revision 1.4 2003/06/18 13:52:43EDT holzhaud
// Changed HHI_BEEPER enum to match Matrix 4080.
// Revision 1.3 2003/06/02 16:38:47EDT holzhaud
// fixed som tab allignments.
// Revision 1.2 2003/05/27 14:01:26EDT holzhaud
// Copied Rev. 1.4.1.3 from the 4500 variant project.
// Revision 1.4.1.3 2003/05/20 16:14:23EDT holzhaud
// Completed integration of the 4080 Power Management struct.
// Revision 1.4.1.2 2003/05/05 16:12:19EDT holzhaud
// Same as rev 1.3.2.2 merged w/ 1.4
// Revision 1.3.2.2 2003/05/05 16:09:07EDT holzhaud
// Modified trigger mode, added Sequence mode, Power management mode and Aimer mode.
// Revision 1.4 2003/04/15 14:13:34EDT montoroj
// - Modified the comment next to dwPrintWeight in HHI_DECODER_CONFIG structure.
// Revision 1.3.2.1 2003/03/24 15:00:12EST holzhaud
// Added the new enumerated trigger modes.
// Revision 1.3 2003/02/20 16:32:49EST montoroj
// - Replaced $LOG$ with $Log: hhiImgrCfg.h  $
// - Replaced Revision 1.10 2008/05/21 16:26:25EDT MontoroJ 
// - Replaced - Removed all references to data formatting.
// - Replaced Revision 1.9 2008/01/25 10:17:39EST MontoroJ 
// - Replaced - Reverting accidental check in of multiple connect versions of these files into the single
// - Replaced   connect version of the SDK
// - Replaced Revision 1.7 2007/08/23 10:19:04EDT MontoroJ 
// - Replaced - Added 4600R presentation mode to trigger modes. (trig mode 8)
// - Replaced Revision 1.6 2007/08/14 09:14:10EDT MontoroJ 
// - Replaced - Added more beeper support.
// - Replaced Revision 1.5 2007/07/31 11:49:00EDT MontoroJ 
// - Replaced - Changed FF_BINARY_RAW back to FF_RAW_BINARY.  What was I thinking!??!
// - Replaced Revision 1.4 2007/07/31 11:16:50EDT MontoroJ 
// - Replaced - Modified HHI_BEEPER structure:
// - Replaced     - Renamed bBeepOnDecode --> dwBeepsOnDecode
// - Replaced     - Added dwBeepsOnError
// - Replaced     - Added dwGoodReadFreq
// - Replaced     - Added dwErrorFreq
// - Replaced Revision 1.3 2007/07/18 12:23:56EDT MontoroJ 
// - Replaced - Cleaned up some of the naming convention issues with some of the structures and masks.
// - Replaced Revision 1.2 2007/06/21 12:51:44EDT MontoroJ 
// - Replaced - Removed the nCaptureFrames, nOverExposed and nUnderExposed members from the
// - Replaced   HHI_IMAGE structure.  nGain and nExposure have been left in since the imager sends 
// - Replaced   items for these members (although it looks like the firmware does not actually fill them in). 
// - Replaced Revision 1.3 2007/03/29 13:17:28EST MontoroJ 
// - Replaced - Added dwTargetPercentile to HHI_IMAGE_ACQUISITION structure.
// - Replaced - Added bAdaptiveTextFilter to HHI_IMAGE_TRANSFER structure.
// - Replaced Revision 1.2 2007/02/28 15:52:41EST MontoroJ 
// - Replaced - Updated the module header information (specifically the copyright)
// - Replaced Revision 1.26 2005/11/07 10:03:59EST MontoroJ 
// - Replaced - Updated max value for the HHI_POWER_SETTINGS aimer delay to 4000 (4 seconds)
// - Replaced Revision 1.25 2005/07/26 16:37:51EDT MontoroJ 
// - Replaced - Added Noise Filter option to HHI_IMAGE_TRANSFER
// - Replaced - Added Decoder Revision and Scan Driver Revision to HHI_VERSION_INFO
// - Replaced - Added Auto Aimer Timeout to HHI_POWER_SETTINGS.
// - Replaced - Added UPC Addenda Delay, Composite Code Delay and Concatenate Code Delay to
// - Replaced   HHI_DECODER_CONFIG.
// - Replaced Revision 1.24 2005/06/27 15:06:04EDT MontoroJ 
// - Replaced - Added BOOL setting to the HHI_IMAGE_ACQUISITION structure for setting the VGA
// - Replaced   compatible image mode for 5000VGA and MegaPixel imagers.
// - Replaced Revision 1.23 2005/06/22 09:24:28EDT MontoroJ 
// - Replaced - Renamed GREEN_LEDS / RED_LEDS  SECONDAY_LEDS / PRIIMARY_LEDS
// - Replaced Revision 1.22 2005/05/26 18:06:20EDT MontoroJ 
// - Replaced - Moved HHI_ENGINE_INFO structure from hhiEngineInfo to here.
// - Replaced Revision 1.21 2005/05/11 09:01:39EDT MontoroJ 
// - Replaced - Modified Version Info structure and code to be backwardly compatible with last 4080 SDK.
// - Replaced Revision 1.20 2005/05/04 16:13:41EDT MontoroJ 
// - Replaced - Added enums for IT5000 imagers (other than 5000 VGA)
// - Replaced Revision 1.19 2005/04/05 15:12:23EDT MontoroJ 
// - Replaced - Added IT5X00 variant information to existing structures:
// - Replaced     - Added illumination color to HHI_DECODER_CONFIG.
// - Replaced     - Made the following changes to HHI_VERSION_INFO:
// - Replaced         - Changed tcPartNumber to tcFirmwarePartNumber.
// - Replaced         - Added tcManufacturersId for engine ID and Checksum.
// - Replaced Revision 1.18 2005/01/26 13:04:52EST montoroj 
// - Replaced - Added ifdef around DataFormater in ConfigItems_t
// - Replaced Revision 1.17 2004/12/17 11:50:06EST montoroj
// - Replaced - Added structures which are currently defined out for data formatting.
// - Replaced Revision 1.16 2004/09/16 10:10:12EDT montoroj
// - Replaced - Removed HHI_SEQUENCE structure and replaced it with HHI_SEQUENCE_MODE structure.
// - Replaced   The new structure allows the caller to specify barcodes by SYM_ID, length and matching'
// - Replaced   string (from start only as per normal sequence mode) up to 12 barcodes instead of having
// - Replaced   to build the sequence string required by the imager.
// - Replaced Revision 1.15 2004/08/02 11:08:32EDT montoroj
// - Replaced - Added min/max defines for exposure so developers know what they are.
// - Replaced Revision 1.14 2004/06/17 11:28:45EDT montoroj
// - Replaced - Added define of BEEPER_VOLUME which was renamed HHI_BEEPER_VOLUME in SDK
// - Replaced   but since SDK and Examples have different SharedInclude directories, it was never put
// - Replaced   into Examples version of code.  This allows people to use either header with either project.
// - Replaced Revision 1.13 2004/05/11 15:57:56EDT montoroj
// - Replaced - Modified Image Transfer Structure by adding:
// - Replaced     dwEdgeEnhancement	- EDGE_ENHANCEMENT_MASK
// - Replaced     dwGammaCorrection	- GAMMA_CORRECTION_MASK
// - Replaced     dwTextEnhancement	- TEXT_ENHANCEMENT_MASK
// - Replaced     bInfinityFilter	- INFINITY_FILTER_MASK
// - Replaced     bFlipImage		- FLIP_IMAGE_MASK
// - Replaced also added min and max for DWORD values.
// - Replaced Revision 1.12 2004/05/05 11:59:50EDT montoroj
// - Replaced - Renamed BEEPER_VOLUME to HHI_BEEPER_VOLUME
// - Replaced - Added comments
// - Replaced - Added sleep mask defines (overloaded names) that make sense.
// - Replaced Revision 1.11 2004/04/13 14:34:27EDT montoroj
// - Replaced - Changed comments that describe ranges of trigger and serial low power timeouts.
// - Replaced Revision 1.10 2004/03/24 15:58:05EST montoroj
// - Replaced - Added HHI_SNAP_AND_SHIP to HHI_TRIG_MODES Trigger modes enum
// - Replaced - Added some duplicatenames for some of the power masks that might be easier for a
// - Replaced   developer to understand.
// - Replaced Revision 1.9 2003/12/02 13:35:28EST holzhaud
// - Replaced
// - Replaced Revision 1.8 2003/07/07 13:07:56EDT holzhaud
// - Replaced Removed Low Power Imaging from the POWER SETTINGS struct.
// - Replaced Revision 1.7 2003/06/30 23:28:15EDT holzhaud
// - Replaced Fixed Clock Speed enum type... wrong values; also removed an unused power mask #define.
// - Replaced Revision 1.6 2003/06/26 15:00:55EDT holzhaud
// - Replaced minor change in TRIGMSK
// - Replaced Revision 1.5 2003/06/26 11:37:17EDT holzhaud
// - Replaced Changed Decode, Beeper, and Trigger structures and enum types because of
// - Replaced modified/changed/deleted/included new 4080 menu commands.
// - Replaced Revision 1.4 2003/06/18 13:52:43EDT holzhaud
// - Replaced Changed HHI_BEEPER enum to match Matrix 4080.
// - Replaced Revision 1.3 2003/06/02 16:38:47EDT holzhaud
// - Replaced fixed som tab allignments.
// - Replaced Revision 1.2 2003/05/27 14:01:26EDT holzhaud
// - Replaced Copied Rev. 1.4.1.3 from the 4500 variant project.
// - Replaced Revision 1.4.1.3 2003/05/20 16:14:23EDT holzhaud
// - Replaced Completed integration of the 4080 Power Management struct.
// - Replaced Revision 1.4.1.2 2003/05/05 16:12:19EDT holzhaud
// - Replaced Same as rev 1.3.2.2 merged w/ 1.4
// - Replaced Revision 1.3.2.2 2003/05/05 16:09:07EDT holzhaud
// - Replaced Modified trigger mode, added Sequence mode, Power management mode and Aimer mode.
// - Replaced Revision 1.3.2.1 2003/03/24 15:00:12EST holzhaud
// - Replaced Added the new enumerated trigger modes.
