/*
******************************************************************************
*
*               Copyright (c) 2002-2007 Hand Held Products Inc.
*
*                         All Rights Reserved.
*
******************************************************************************
*
* $RCSfile: hhiImgrSdk.h $
* $Revision: 1.6 $
* $Date: 2008/04/24 13:15:22EDT $
* $Author: MontoroJ $
*
*  File:        hhiImgrSdk.h
*
*  Description: Main HHP SDK header file.  This file contains the API interface
*               prototypes and communication structures.
*
*  Rev. Date    By     Revision Notes
*  ----------   ---    ----------------
*  07/24/2002   JCM    Original Release
*  11/14/2002   JCM    Removed dependency on ENGINE_API
*  01/10/2003   JCM    Added hhpAcquireIntelligentImage() which also added 2
*                      members to HHI_EVENT_TYPE (HHI_INTELIMG_BARCODE_EVENT
*                      and HHI_INTELIMG_IMAGE_EVENT).
*  03/06/2003   JCM    Added bSendBinary to HHI_INTEL_IMG structure.
*  09/08/2004   JCM    - Added hhpStartImageStream() function.
*                      - Added default parameters for hhpNamedConnect() and
*                        hhpNamedConnect().
*                      - Added imagerType enum & imager type member to
*                      capabilities struct.
*  07/19/2005   JCM    Added new function hhpSendPlugAndPlayCommand and enum
*                      HHI_PLUG_N_PLAY.
*
******************************************************************************
*/

#ifndef HHIIMGRSDK_H

    #define HHIIMGRSDK_H

    // Includes for configuration
    #include <windows.h>
    #include "hhiSymCfg.h"
    #include "hhiImgrCfg.h"
    // The following ifdef block is the standard way of creating macros which make exporting
    // from a DLL simpler. All files within this DLL are compiled with the HHPIMGRSDK_EXPORTS
    // symbol defined on the command line. this symbol should not be defined on any project
    // that uses this DLL. This way any other project whose source files include this file see
    // HHPIMGRSDK_API functions as being imported from a DLL, wheras this DLL sees symbols
    // defined with this macro as being exported.
    #ifndef HHISDK_API
        #ifndef _WIN32_WCE
            #if defined(_USRDLL)
                #define HHISDK_API      __declspec(dllexport)
            #else
                #if defined _MANAGED_CPP
                    #define HHISDK_API  __declspec(dllexport)
                #else
                    #define HHISDK_API  __declspec(dllimport)
                #endif
            #endif
        #else
            #if defined(_USRDLL)
                #define HHISDK_API      __declspec(dllexport)
            #else
                #define HHISDK_API      __declspec(dllimport)
            #endif
            #define CLK_TCK             1000
            #define CLOCKS_PER_SEC      CLK_TCK
        #endif
    #endif

    // Basic defines.
    #define HHISDK_API_RESPONSE_LEN             1024
    #define MAX_SEND_MESSAGE_BYTES              8192
    #define CURRENT_DECODE_TIMEOUT              0xffffffff
    // Defines
    #define ENGINE_API_RESPONSE_LEN         HHISDK_API_RESPONSE_LEN
    //-----------------------------------------------------------------------------
    //  These are the possible return values for all API functions
    //  They indicate either success, or the type of error encountered.
    //-----------------------------------------------------------------------------
    typedef enum
    {
        RESULT_INITIALIZE = -1,
        RESULT_SUCCESS  = 0,                // Operation was successful
        RESULT_ERR_BADFILENAME,
        RESULT_ERR_BADPORT,
        RESULT_ERR_BADREGION,
        RESULT_ERR_DRIVER,              //  Error occurred communicating with engine driver
        RESULT_ERR_ENGINEBUSY,
        RESULT_ERR_FILE,
        RESULT_ERR_FILEINCOMPATIBLE,
        RESULT_ERR_FILEINVALID,
        RESULT_ERR_MEMORY,
        RESULT_ERR_NODECODE,
        RESULT_ERR_NODRIVER,
        RESULT_ERR_NOIMAGE,
        RESULT_ERR_NORESPONSE,
        RESULT_ERR_NOTCONNECTED,
        RESULT_ERR_PARAMETER,           // One of the function parameters was invalid
        RESULT_ERR_UNSUPPORTED,         // The operation was not supported by the engine
        RESULT_ERR_UPGRADE,
        RESULT_ERR_MENUDECODE,
        RESULT_ERR_REFLASH,
        RESULT_ERR_NOTRIGGER,           // During wait for decode the function we call to check a trigger return that it was released
        RESULT_ERR_BADSMARTIMAGE,
        RESULT_ERR_SMARTIMAGETOOLARGE,
        RESULT_ERR_BUFFER_TOO_SMALL,
        RESULT_ERR_PORT_IN_USE,
        RESULT_EOT = 256,
        RESULT_ERR_READTHREAD_START,
        RESULT_ERR_READTHREAD_STOP,
        RESULT_ERR_POLLEVENT,
        RESULT_ERR_WRONGRESULTSTRUCT,
        RESULT_ERR_USER_CANCEL,
        RESULT_ERR_NAK,
        RESULT_ERR_COMPRESSION_FAILED,
        RESULT_ERR_DECOMPRESSION_FAILED,
        RESULT_ERR_CAPTURE_IMAGE_FAILED,
        RESULT_ERR_SHIP_IMAGE_FAILED,
        RESULT_ERR_CONNECT_BOOT_CODE,
        RESULT_ERR_BAUD_TO_HIGH,
        RESULT_ERR_INVALID_COMM_PARAMS,
        RESULT_ERR_UNICODE_UNSUPPORTED,
        RESULT_ERR_INTERNAL_ERROR,
        RESULT_ERR_NOINTELBARCODE,
        RESULT_ERR_BADINTELIMAGE,
        RESULT_ERR_NOINTELIMAGE,
        RESULT_ERR_DLL_FILE,
        RESULT_ERR_DECODER_INIT_FAILED,
        RESULT_ERR_IMAGE_PROCESSING_FAILED,
        RESULT_ERR_UNSUPPORTED_ENGINE,
        RESULT_ERR_SYMBOLOGY_HAS_NO_RANGE,
        RESULT_ERR_COMMUNICATIONS_ERROR,
        RESULT_ERR_ASYNC_CALLS_NOT_AVAILABLE,
        RESULT_ERR_ASYNC_CALL_NOT_ALLOWED,
        RESULT_ERR_NOTHING_TO_DO

    } Result_t;
    //-----------------------------------------------------------------------------
    // Setup type
    //-----------------------------------------------------------------------------
    typedef enum
    {
        SETUP_TYPE_DEFAULT = 0,
        SETUP_TYPE_CURRENT,
        SETUP_TYPE_TEMPORARY

    } SetupType_t;
    #define  SETUP_TYPE_RAM     SETUP_TYPE_TEMPORARY
    // Maximum text message size (this is also the maximum allowed in a 'No Wait for
    // response hhiSendCommand() call)
    #define MAX_TEXT_MSG_LENGTH     (MAX_MESAGE_LENGTH * 2)
    // Text message type
    typedef struct _tagHHI_TEXT_MSG
    {
        DWORD   dwStructSize;
        TCHAR   tcTextMsg[ MAX_TEXT_MSG_LENGTH ];
        DWORD   nLength;

    } HHI_TEXT_MSG, *PHHI_TEXT_MSG;
    //------------------------------------------------------------------
    //  Intelligent Image Capture
    //------------------------------------------------------------------
    typedef struct _tagIntellImgDesc_t
    {
        DWORD   dwStructSize;
        DWORD   dwAspectRatio;  // ratioof barcode height to narrow elem width
        LONG    nOffsetX;       // offset in X direction, relative to barcode center
        LONG    nOffsetY;       // offset in Y direction
        DWORD   dwWidth;        // width of image in IntellBarcodeUnits
        DWORD   dwHeight;       // height of image
        SIZE    maxImgSize;     // Maximum width & height for intell image
        BOOL    bSendBinary;    // Have reader binarize data before transfer.

    } IntellImgDesc_t, HHI_INTEL_IMG, *PHHI_INTEL_IMG;
    // Serial port baud rates
    typedef enum
    {
        SERIAL_BAUD_300 = 300,
        SERIAL_BAUD_600 = 600,
        SERIAL_BAUD_1200 = 1200,
        SERIAL_BAUD_2400 = 2400,
        SERIAL_BAUD_4800 = 4800,
        SERIAL_BAUD_9600 = 9600,
        SERIAL_BAUD_19200 = 19200,
        SERIAL_BAUD_38400 = 38400,
        SERIAL_BAUD_57600 = 57600,
        SERIAL_BAUD_115200 = 115200,
        SERIAL_BAUD_230400 = 230400,
        SERIAL_BAUD_460800 = 460800,
        SERIAL_BAUD_921600 = 921600

    } HHI_BAUD_RATE;
    // Serial data bits
    typedef enum
    {
        SERIAL_DATA_BITS_7 = 7,
        SERIAL_DATA_BITS_8

    } HHI_DATA_BITS;
    // Parity
    typedef enum
    {
        SERIAL_PARITY_NONE = 'N',
        SERIAL_PARITY_ODD = 'O',
        SERIAL_PARITY_EVEN = 'E',
        SERIAL_PARITY_MARK = 'M',
        SERIAL_PARITY_SPACE = 'S'

    } HHI_PARITY;
    // Stop bits.
    typedef enum
    {
        SERIAL_ONE_STOPBITS = 1,
        SERIAL_TWO_STOPBITS,

    } HHI_STOP_BITS;
    // Serial Port Config
    typedef struct _tagHHI_SERIAL_PORT_CONFIG
    {
        DWORD           dwStructSize;
        HHI_BAUD_RATE   baudRate;
        HHI_DATA_BITS   dataBits;
        HHI_PARITY      parity;
        HHI_STOP_BITS   stopBits;
        BOOL            bAutoBaud;

    } HHI_SERIAL_PORT_CONFIG, *PHHI_SERIAL_PORT_CONFIG;
    // Decoder Symbology Support
    typedef enum
    {
        HHI_1D_CODES_ONLY=0,
        HHI_1D_AND_PDF_CODES,
        HHI_1D_AND_2D_CODES

    } DecoderType_t, DECODER_TYPE, HHI_DECODER_TYPE;
    // Imager Type (Decoded Out or Non Decoded Out)
    typedef enum
    {
        HHI_UNKNOWN_IMAGER = 0,
        HHI_LINEAR_IMAGER,
        HHI_LINEAR_IMAGER_USB,
        // Imager 4000 variants
        HHI_DECODED_IMAGER_4080 = ((int)TYPE_IT4000 * 10),
        HHI_DECODED_IMAGER_4080_USB = (HHI_DECODED_IMAGER_4080+1),
        // Imager 5000 variants
        HHI_DECODED_IMAGER_5080VGA = ((int)TYPE_IT5X00VGA_PSOC * 10),
        HHI_DECODED_IMAGER_5080VGA_USB = (HHI_DECODED_IMAGER_5080VGA+1),
        // Imager 5000 VGA with PSOC variants
        HHI_DECODED_IMAGER_5080VGA_PSOC = ((int)TYPE_IT5X00VGA_PSOC * 10),
        HHI_DECODED_IMAGER_5080VGA_PSOC_USB = (HHI_DECODED_IMAGER_5080VGA_PSOC+1),
        // Imager 5000  variants
        HHI_DECODED_IMAGER_5080 = ((int)TYPE_IT5X00_PSOC * 10),
        HHI_DECODED_IMAGER_5080_USB = (HHI_DECODED_IMAGER_5080+1),
        // Imager 5000 with PSOC variants
        HHI_DECODED_IMAGER_5080_PSOC = ((int)TYPE_IT5X00_PSOC * 10),
        HHI_DECODED_IMAGER_5080_PSOC_USB = (HHI_DECODED_IMAGER_5080_PSOC+1),
        // MegaPixel with PSOC variants (All megapixels have psoc)
        HHI_DECODED_MEGAPIXEL_IMAGER = ((int)TYPE_IT5X00_PSOC * 20),
        HHI_DECODED_MEGAPIXEL_IMAGER_USB = (HHI_DECODED_MEGAPIXEL_IMAGER+1)

    } ImagerType_t, IMAGER_TYPE, HHI_IMAGER_TYPE;
    // Other defines for imager type.
    #define HHI_DECODED_IMAGER          HHI_DECODED_IMAGER_4080
    #define HHI_DECODED_IMAGER_USB      HHI_DECODED_IMAGER_4080_USB
    // Imager capabilities structure
    typedef struct _tagHHI_IMAGER_CAPS
    {
        DWORD        dwStructSize;
        SIZE         fullImgSize;
        DWORD        dwImgrBpp;
        DECODER_TYPE decoderType;
        IMAGER_TYPE  imagerType;

    } HHI_IMAGER_CAPS, *PHHI_IMAGER_CAPS;
    // Event type enum
    typedef enum
    {
        HHI_BARCODE_EVENT=0,         // HHI_DECODE_MSG
        HHI_IMAGE_EVENT,             // HHI_IMAGE
        HHI_TEXT_MSG_EVENT,          // HHI_TEXT_MSG
        HHI_INTELIMG_BARCODE_EVENT,  // HHI_DECODE_MSG
        HHI_INTELIMG_IMAGE_EVENT,    // HHI_IMAGE
        // Not fully implemented.
        HHI_TRIGGER_EVENT            // BOOL pointer (on/off) Notification of
                                     // a hardware trigger when Trigger mode 5.
    } hhiEventType_t, HHI_EVENT_TYPE, *PHHI_EVENT_TYPE;
    // Connection types
    typedef enum
    {
        HHI_COM1=0,HHI_COM2,HHI_COM3,HHI_COM4,HHI_COM5,HHI_COM6,HHI_COM7,HHI_COM8,HHI_COM9,
        HHI_COM10,HHI_COM11,HHI_COM12,HHI_COM13,HHI_COM14,HHI_COM15,HHI_COM16,HHI_COM17,HHI_COM18,HHI_COM19,
        HHI_COM20,HHI_COM21,HHI_COM22,HHI_COM23,HHI_COM24,HHI_COM25,HHI_COM26,HHI_COM27,HHI_COM28,HHI_COM29,
        HHI_COM30,HHI_COM31,HHI_COM32,HHI_COM33,HHI_COM34,HHI_COM35,HHI_COM36,HHI_COM37,HHI_COM38,HHI_COM39,
        HHI_COM40,HHI_COM41,HHI_COM42,HHI_COM43,HHI_COM44,HHI_COM45,HHI_COM46,HHI_COM47,HHI_COM48,HHI_COM49,
        HHI_COM50,HHI_COM51,HHI_COM52,HHI_COM53,HHI_COM54,HHI_COM55,HHI_COM56,HHI_COM57,HHI_COM58,HHI_COM59,
        HHI_COM60,HHI_COM61,HHI_COM62,HHI_COM63,HHI_COM64,HHI_COM65,HHI_COM66,HHI_COM67,HHI_COM68,HHI_COM69,
        HHI_COM70,HHI_COM71,HHI_COM72,HHI_COM73,HHI_COM74,HHI_COM75,HHI_COM76,HHI_COM77,HHI_COM78,HHI_COM79,
        HHI_COM80,HHI_COM81,HHI_COM82,HHI_COM83,HHI_COM84,HHI_COM85,HHI_COM86,HHI_COM87,HHI_COM88,HHI_COM89,
        HHI_COM90,HHI_COM91,HHI_COM92,HHI_COM93,HHI_COM94,HHI_COM95,HHI_COM96,HHI_COM97,HHI_COM98,HHI_COM99,
        HHI_COM100,HHI_COM101,HHI_COM102,HHI_COM103,HHI_COM104,HHI_COM105,HHI_COM106,HHI_COM107,HHI_COM108,HHI_COM109,
        HHI_COM110,HHI_COM111,HHI_COM112,HHI_COM113,HHI_COM114,HHI_COM115,HHI_COM116,HHI_COM117,HHI_COM118,HHI_COM119,
        HHI_COM120,HHI_COM121,HHI_COM122,HHI_COM123,HHI_COM124,HHI_COM125,HHI_COM126,HHI_COM127,HHI_COM128,HHI_COM129,
        HHI_COM130,HHI_COM131,HHI_COM132,HHI_COM133,HHI_COM134,HHI_COM135,HHI_COM136,HHI_COM137,HHI_COM138,HHI_COM139,
        HHI_COM140,HHI_COM141,HHI_COM142,HHI_COM143,HHI_COM144,HHI_COM145,HHI_COM146,HHI_COM147,HHI_COM148,HHI_COM149,
        HHI_COM150,HHI_COM151,HHI_COM152,HHI_COM153,HHI_COM154,HHI_COM155,HHI_COM156,HHI_COM157,HHI_COM158,HHI_COM159,
        HHI_COM160,HHI_COM161,HHI_COM162,HHI_COM163,HHI_COM164,HHI_COM165,HHI_COM166,HHI_COM167,HHI_COM168,HHI_COM169,
        HHI_COM170,HHI_COM171,HHI_COM172,HHI_COM173,HHI_COM174,HHI_COM175,HHI_COM176,HHI_COM177,HHI_COM178,HHI_COM179,
        HHI_COM180,HHI_COM181,HHI_COM182,HHI_COM183,HHI_COM184,HHI_COM185,HHI_COM186,HHI_COM187,HHI_COM188,HHI_COM189,
        HHI_COM190,HHI_COM191,HHI_COM192,HHI_COM193,HHI_COM194,HHI_COM195,HHI_COM196,HHI_COM197,HHI_COM198,HHI_COM199,
        HHI_COM200,HHI_COM201,HHI_COM202,HHI_COM203,HHI_COM204,HHI_COM205,HHI_COM206,HHI_COM207,HHI_COM208,HHI_COM209,
        HHI_COM210,HHI_COM211,HHI_COM212,HHI_COM213,HHI_COM214,HHI_COM215,HHI_COM216,HHI_COM217,HHI_COM218,HHI_COM219,
        HHI_COM220,HHI_COM221,HHI_COM222,HHI_COM223,HHI_COM224,HHI_COM225,HHI_LAST_COMM_PORT = 255

    } HHI_CONNECT_TYPE, *PHHI_CONNECT_TYPE;
    // HHP Action Commands
    typedef enum
    {
        HHI_AIMER_CMD=0,
        HHI_ILLUMINATION_CMD,   // No longer supported by imagers.
        HHI_BEEP_CMD

    } HHI_ACTION, *PHHI_ACTION;
    // On/Off enum
    enum
    {
        HHI_OFF=0,
        HHI_ON=1

    };
    // Beep Execute enum
    enum
    {
        HHI_SINGLE_BEEP=0,
        HHI_DOUBLE_BEEP,
        HHI_GOOD_READ_BEEP,
        HHI_ERROR_BEEP
    };
    // Plug and Play Command Enum
    typedef enum
    {
        PNP_OCR_PASSPORT=0

    } HHI_PLUG_N_PLAY;
    // Windows message IDs
    #define WM_HHI_EVENT_HWND_MSG       (WM_USER + 14534)
    #define WM_HHI_TRANSFER_HWND_MSG    (WM_USER + 14535)
    #define WM_HHI_PROGRESS_HWND_MSG    WM_HHI_TRANSFER_HWND_MSG
    #define WM_HHI_IMAGER_FLASHING      (WM_USER + 14536)
    #define WM_HHI_POWER_EVENT          (WM_USER + 14537)  // Windows CE only
    #define WM_HHI_SEQ_BARCODE_READ     (WM_USER + 14538)

#ifdef __cplusplus
  extern "C"
  {
#endif  /* __cplusplus */
    // Callback prototype
    typedef BOOL (CALLBACK *HHIEVENTCALLBACK)( HHI_EVENT_TYPE eventType,DWORD dwBytes );
    // Connect/Disconnect functions.
    HHISDK_API Result_t hhiConnect( HHI_CONNECT_TYPE connectType,PVOID pStruct );
    HHISDK_API Result_t hhiNamedConnect( PTCHAR ptcConnectName,PVOID pStruct );
    HHISDK_API Result_t hhiDisconnect( void );
    HHISDK_API BOOL     hhiEngineConnected( void );
    // Miscellaneous Error Code Message function.
    HHISDK_API Result_t hhiGetErrorMessage( Result_t nErrorCode,PTCHAR ptcErrorMsg,int nMaxChars );
    // Asynchronous event functions.
    HHISDK_API Result_t hhiSetAsyncMethods( HANDLE hEventHandle,HWND hWndHandle,HHIEVENTCALLBACK EventCallback );
    HHISDK_API Result_t hhiGetAsyncResult( PHHI_EVENT_TYPE pEventType,PVOID pResultStruct );
    HHISDK_API Result_t hhiCancelIo( void );
    // Whole config functions
    HHISDK_API Result_t hhiReadConfigStream( PBYTE puchCfgStream,int nMaxLen,PINT pnBytesReturned );
    HHISDK_API Result_t hhiWriteConfigStream( PBYTE puchCfgStream,int nLen,BOOL bWriteToFlash );
    // General config functions
    HHISDK_API Result_t hhiReadConfigItem( SetupType_t cfgType,ConfigItems_t item,PVOID pStruct );
    HHISDK_API Result_t hhiWriteConfigItem( ConfigItems_t item,PVOID pStruct,BOOL bWriteToFlash );
    HHISDK_API Result_t hhiSetConfigItemToDefaults( ConfigItems_t item,BOOL bWriteToFlash );
    HHISDK_API Result_t hhiReadImagerCapabilities( PHHI_IMAGER_CAPS pImgrCaps );
    // Get Image Engine Information (5000 engine with a PSOC only)
    HHISDK_API Result_t hhiReadEngineInfo( PHHI_ENGINE_INFO pEngInfo );
    // Symbology specific functions.
    HHISDK_API Result_t hhiReadSymbologyConfig( SetupType_t cfgType,int nSymbol,PVOID pvSymStruct );
    HHISDK_API Result_t hhiWriteSymbologyConfig( int nSymId,PVOID pvSymStruct,BOOL bWriteToFlash );
    HHISDK_API Result_t hhiSetSymbologyDefaults( int nSymId,BOOL bWriteToFlash );
    HHISDK_API Result_t hhiEnableDisableSymbology( int nSymId,BOOL bEnable,BOOL bWriteToFlash );
    HHISDK_API Result_t hhiReadSymbologyRangeMaxMin( int nSymId,PLONG nMinVals,PLONG nMaxVals );
    // Barcode capture support
    HHISDK_API Result_t hhiCaptureBarcode( PHHI_DECODE_MSG pDecodeMsg,DWORD dwTimeout,BOOL bWait );  // Timeout in milliseconds
    HHISDK_API Result_t hhiCaptureRawBarcode( PHHI_RAW_DECODE_MSG pDecodeMsg,DWORD dwTimeout,BOOL bWait );  // Timeout in milliseconds
    // Image capture/transfer
    HHISDK_API Result_t hhiAcquireImage( PHHI_IMAGE pImg,PHHI_IMAGE_TRANSFER pImgTrans,PHHI_IMAGE_ACQUISITION pImgAcqu,BOOL bWait );
    HHISDK_API Result_t hhiAcquireImageAutoCrop( PHHI_IMAGE pImg,PHHI_IMAGE_TRANSFER pImgTrans,PHHI_IMAGE_ACQUISITION pImgAcqu,BOOL bWait );
    HHISDK_API Result_t hhiGetLastImage( PHHI_IMAGE pImg,PHHI_IMAGE_TRANSFER pImgTrans,BOOL bWait );
    HHISDK_API Result_t hhiGetLastImageAutoCrop( PHHI_IMAGE pImg,PHHI_IMAGE_TRANSFER pImgTrans,BOOL bWait );
    // Intelligent Image Capture
    HHISDK_API Result_t hhiAcquireIntelligentImage( PHHI_INTEL_IMG pIntelImg,PHHI_DECODE_MSG pDecodeMsg,
                                                    DWORD dwTimeout,PHHI_IMAGE pImg,BOOL bWait );
    HHISDK_API Result_t hhiRawAcquireIntelligentImage( PHHI_INTEL_IMG pIntelImg,PHHI_RAW_DECODE_MSG pRawDecodeMsg,
                                                       DWORD dwTimeout,PHHI_IMAGE pImg,BOOL bWait );
    // Command only interface
    HHISDK_API Result_t hhiSendActionCommand( HHI_ACTION actionCmd,int nVal );
    // Specify a hardware line (sleep detection, trigger etc) dll file name
    HHISDK_API Result_t hhiSetHardwareLineDllFileName( PTCHAR ptcHwrFilename );
    // Send Command interface
    HHISDK_API Result_t hhiSendMessage( PBYTE puchMsg,int nLen,BOOL bSendRaw,PBYTE puchReply,int nLenToRead,PINT pnRetLen );
    // Send Plug & Play commands (set specific configuration by single command)
    HHISDK_API Result_t hhiSendPlugAndPlayCommand( HHI_PLUG_N_PLAY pnpCmd );
    // Firmware upgrade function.
    HHISDK_API Result_t hhiUpgradeFirmware( const PTCHAR ptcFirmwareFilename,PDWORD pdwTransferPercent,HWND hTransferNotifyHwnd );

#ifdef __cplusplus
  }
#endif

#endif

// $Log: hhiImgrSdk.h  $
// Revision 1.6 2008/04/24 13:15:22EDT MontoroJ 
// - Added SETUP_TYPE_TEMPORARY so that the RAM only settings can be read.
// - Fixed bug where synchronous IQ Image capture was failing. MKS #4462
// Revision 1.5 2008/01/25 10:17:37EST MontoroJ 
// - Reverting accidental check in of multiple connect versions of these files into the single
//   connect version of the SDK
// Revision 1.3 2007/08/14 09:14:07EDT MontoroJ
// - Added more beeper support.
// Revision 1.2 2007/06/19 11:25:04EDT MontoroJ
// - Code clean up related to doing documentation and the fact that this SDK is Windows only.
// Revision 1.3 2007/03/05 15:23:11EST MontoroJ
// - Increased size of text message buffer to accomodate reading of asynchronous '?' command.
// Revision 1.2 2007/02/28 15:52:42EST MontoroJ
// - Updated the module header information (specifically the copyright)
// Revision 1.17 2005/08/12 15:28:42EDT MontoroJ
// - Added an error code for Communications Error.
// Revision 1.16 2005/07/26 16:38:44EDT MontoroJ
// - Added hhpSendPlugAndPlayCommand()
// - Added enum HHI_PLUG_N_PLAY
// Revision 1.15 2005/05/26 18:08:40EDT MontoroJ
// - Moved prototype for hhpReadEngineInfo() from hhpEngineInfo.h
// - Added __declspec( dllimport ) for app include. Used to be blank. This actually helps
//   the loader to be more efficient.
// Revision 1.14 2005/05/04 16:13:43EDT MontoroJ
// - Added enums for IT5000 imagers (other than 5000 VGA)
// Revision 1.13 2005/04/05 15:14:14EDT MontoroJ
// - Modified ImagerType enumeration to reflect information received from new engine ID. This
//   includes whether imager is VGA and PSOC.
// - Added defines for old types as new values.
// Revision 1.12 2005/01/26 13:06:57EST montoroj
// - Added comment on HHI_ILLUMINATION_CMD that it is no longer supported.
// Revision 1.11 2005/01/14 11:03:11EST montoroj
// - Added error code for Symbology does not have range.
// - Added prototype for hhpReadSymbologyRangeMaxMin()
// Revision 1.10 2004/12/17 11:51:29EST montoroj
// - Added prototype for hhpRawAcquireIntelligentImage() so that a user can receive the byte
//   barcode when doing an intelligent image capture.
// Revision 1.9 2004/09/24 14:40:17EDT montoroj
// - Fixed typo in imager type enum.
// Revision 1.8 2004/09/16 10:39:46EDT montoroj
// - On further reflection, I made default parameters for hhpConnect() & hhpNamedConnect()
//   dependent on C++ compile. Otherwise they are defined without default parameters. (C does
//   not support default parameter values)
// Revision 1.7 2004/09/16 10:07:25EDT montoroj
// - Added hhpStartImageStream() which is unsupported for the decoded engines so it returns
//   RESULT_ERR_UNSUPPORTED_ENGINE (used by  non-decoded out engines like the 4000)
// - Added default parameters for hhpConnect() and hhpNamedConnect()
// - Added enumerated type: ImagerType_t.  The types correspond to decoded out serial,
//   decoded out USB and non-decoded out.
// - Added member to HHI_IMAGER_CAPS for imager type.
// Revision 1.6 2004/05/06 09:47:43EDT montoroj
// - Added support for trigger event which will work great once they really make it work in the
//    firmware.
// Revision 1.5 2004/03/24 16:52:06EST montoroj
// See checkin of these versions in the Matrix4080SDK project
// Revision 1.4 2004/01/06 14:27:06EST holzhaud
// Changed 'NET_DLL' define to '_MANAGED_CPP', canged HHI_LAST_COMM_PORT to = 255
// and added prototype for hhpCaptureRawBarcode().
// Revision 1.3 2003/06/26 13:38:26EDT keysb
// Added hhpCloseConnection and hhpOpenConnection to close a device handle or open a new device handle in CComImager without closing CComImager.
// Revision 1.2 2003/06/22 21:40:36EDT holzhaud
// Comments only.
// Revision 1.1 2003/06/19 11:54:30EDT holzhaud
// Initial revision
// Member added to project d:/MKS_IT/SDK/Matrix_SDK_Examples/Matrix_SDK_Examples.pj
// Revision 1.1 2003/05/15 10:46:31EDT montoroj
// Initial revision
// Member added to project d:/MKS_IT/SDK/Matrix_SDK/Matrix_SDK.pj
// Revision 1.5 2003/04/02 16:18:30EST montoroj
// - Added CURRENT_DECODE_TIMEOUT defined to be 0xffffffff
// Revision 1.4 2003/03/12 15:12:35EST montoroj
// - Added bSendBinary to HHI_INTEL_IMG structure
// Revision 1.3 2003/02/20 16:32:53EST montoroj
// - Replaced $LOG$ with $Log: hhiImgrSdk.h  $
// - Replaced Revision 1.6 2008/04/24 13:15:22EDT MontoroJ 
// - Replaced - Added SETUP_TYPE_TEMPORARY so that the RAM only settings can be read.
// - Replaced - Fixed bug where synchronous IQ Image capture was failing. MKS #4462
// - Replaced Revision 1.5 2008/01/25 10:17:37EST MontoroJ 
// - Replaced - Reverting accidental check in of multiple connect versions of these files into the single
// - Replaced   connect version of the SDK
// - Replaced Revision 1.3 2007/08/14 09:14:07EDT MontoroJ
// - Replaced - Added more beeper support.
// - Replaced Revision 1.2 2007/06/19 11:25:04EDT MontoroJ
// - Replaced - Code clean up related to doing documentation and the fact that this SDK is Windows only.
// - Replaced Revision 1.3 2007/03/05 15:23:11EST MontoroJ
// - Replaced - Increased size of text message buffer to accomodate reading of asynchronous '?' command.
// - Replaced Revision 1.2 2007/02/28 15:52:42EST MontoroJ
// - Replaced - Updated the module header information (specifically the copyright)
// - Replaced Revision 1.17 2005/08/12 15:28:42EDT MontoroJ
// - Replaced - Added an error code for Communications Error.
// - Replaced Revision 1.16 2005/07/26 16:38:44EDT MontoroJ
// - Replaced - Added hhpSendPlugAndPlayCommand()
// - Replaced - Added enum HHI_PLUG_N_PLAY
// - Replaced Revision 1.15 2005/05/26 18:08:40EDT MontoroJ
// - Replaced - Moved prototype for hhpReadEngineInfo() from hhpEngineInfo.h
// - Replaced - Added __declspec( dllimport ) for app include. Used to be blank. This actually helps
// - Replaced   the loader to be more efficient.
// - Replaced Revision 1.14 2005/05/04 16:13:43EDT MontoroJ
// - Replaced - Added enums for IT5000 imagers (other than 5000 VGA)
// - Replaced Revision 1.13 2005/04/05 15:14:14EDT MontoroJ
// - Replaced - Modified ImagerType enumeration to reflect information received from new engine ID. This
// - Replaced   includes whether imager is VGA and PSOC.
// - Replaced - Added defines for old types as new values.
// - Replaced Revision 1.12 2005/01/26 13:06:57EST montoroj
// - Replaced - Added comment on HHI_ILLUMINATION_CMD that it is no longer supported.
// - Replaced Revision 1.11 2005/01/14 11:03:11EST montoroj
// - Replaced - Added error code for Symbology does not have range.
// - Replaced - Added prototype for hhpReadSymbologyRangeMaxMin()
// - Replaced Revision 1.10 2004/12/17 11:51:29EST montoroj
// - Replaced - Added prototype for hhpRawAcquireIntelligentImage() so that a user can receive the byte
// - Replaced   barcode when doing an intelligent image capture.
// - Replaced Revision 1.9 2004/09/24 14:40:17EDT montoroj
// - Replaced - Fixed typo in imager type enum.
// - Replaced Revision 1.8 2004/09/16 10:39:46EDT montoroj
// - Replaced - On further reflection, I made default parameters for hhpConnect() & hhpNamedConnect()
// - Replaced   dependent on C++ compile. Otherwise they are defined without default parameters. (C does
// - Replaced   not support default parameter values)
// - Replaced Revision 1.7 2004/09/16 10:07:25EDT montoroj
// - Replaced - Added hhpStartImageStream() which is unsupported for the decoded engines so it returns
// - Replaced   RESULT_ERR_UNSUPPORTED_ENGINE (used by  non-decoded out engines like the 4000)
// - Replaced - Added default parameters for hhpConnect() and hhpNamedConnect()
// - Replaced - Added enumerated type: ImagerType_t.  The types correspond to decoded out serial,
// - Replaced   decoded out USB and non-decoded out.
// - Replaced - Added member to HHI_IMAGER_CAPS for imager type.
// - Replaced Revision 1.6 2004/05/06 09:47:43EDT montoroj
// - Replaced - Added support for trigger event which will work great once they really make it work in the
// - Replaced    firmware.
// - Replaced Revision 1.5 2004/03/24 16:52:06EST montoroj
// - Replaced See checkin of these versions in the Matrix4080SDK project
// - Replaced Revision 1.4 2004/01/06 14:27:06EST holzhaud
// - Replaced Changed 'NET_DLL' define to '_MANAGED_CPP', canged HHI_LAST_COMM_PORT to = 255
// - Replaced and added prototype for hhpCaptureRawBarcode().
// - Replaced Revision 1.3 2003/06/26 13:38:26EDT keysb
// - Replaced Added hhpCloseConnection and hhpOpenConnection to close a device handle or open a new device handle in CComImager without closing CComImager.
// - Replaced Revision 1.2 2003/06/22 21:40:36EDT holzhaud
// - Replaced Comments only.
// - Replaced Revision 1.1 2003/06/19 11:54:30EDT holzhaud
// - Replaced Initial revision
// - Replaced Member added to project d:/MKS_IT/SDK/Matrix_SDK_Examples/Matrix_SDK_Examples.pj
// - Replaced Revision 1.1 2003/05/15 10:46:31EDT montoroj
// - Replaced Initial revision
// - Replaced Member added to project d:/MKS_IT/SDK/Matrix_SDK/Matrix_SDK.pj
// - Replaced Revision 1.5 2003/04/02 16:18:30EST montoroj
// - Replaced - Added CURRENT_DECODE_TIMEOUT defined to be 0xffffffff
// - Replaced Revision 1.4 2003/03/12 15:12:35EST montoroj
// - Replaced - Added bSendBinary to HHI_INTEL_IMG structure
