/*
******************************************************************************
*
*               Copyright (c) 2002-2007 Hand Held Products Inc.
*
*                        All Rights Reserved.
*
******************************************************************************
*
* $RCSfile: hhiSymCfg.h $
* $Revision: 1.5 $
* $Date: 2008/06/08 15:51:04EDT $
* $Author: MontoroJ $
*
*  File:        HhpSymCfg.h
*
*  Description: Header file which contains the HHP decoder configuration struct
*               defines, enumerated types and structures.
*
*  Rev. Date    By     Revision Notes
*  ----------   ---    ----------------
*  06/26/2002   JCM    Original Release
*  11/14/2002   JCM    Removed dependency on ENGINE_API
*
******************************************************************************
*/

#ifndef HHPSYMCFG_H

    #define HHPSYMCFG_H

    //-----------------------------------------------------------------------------
    // Symbology selection constants
    //-----------------------------------------------------------------------------
    enum
    {
        SYM_AZTEC = 0,
        SYM_CODABAR = 2,
        SYM_CODE11,
        SYM_CODE128,
        SYM_CODE39,
        SYM_CODE49,
        SYM_CODE93,
        SYM_GS1_COMPOSITE,
        SYM_DATAMATRIX,
        SYM_EAN8,
        SYM_EAN13,
        SYM_INT25,
        SYM_MAXICODE,
        SYM_MICROPDF,
        SYM_OCR,
        SYM_PDF417,
        SYM_POSTNET,
        SYM_QR,
        SYM_GS1_DATABAR,
        SYM_UPCA,
        SYM_UPCE0,
        SYM_UPCE1,
        SYM_ISBT,
        SYM_BPO,
        SYM_CANPOST,
        SYM_AUSPOST,
        SYM_IATA25,
        SYM_CODABLOCK,
        SYM_JAPOST,
        SYM_PLANET,
        SYM_DUTCHPOST,
        SYM_MSI,
        SYM_TLCODE39,
        SYM_MATRIX25,
		SYM_KORPOST,
        SYM_TRIOPTIC,
        SYM_CODE32,
        SYM_STRT25,
        SYM_PLESSEY,
        SYM_CHINAPOST,
        SYM_TELEPEN,
        SYM_CODE16K,
        SYM_POSICODE,
        SYM_GS1_128,
        SYM_UPUIDTAG,
        SYM_CODE4CB,
        NUM_SYMBOLOGIES,
        SYM_ALL=100
    };
    #define SYM_CODE25          SYM_STRT25
    #define SYM_COMPOSITE       SYM_GS1_COMPOSITE
    #define SYM_RSS             SYM_GS1_DATABAR
    #define SYM_COUPONCODE      SYM_GS1_128
    //-----------------------------------------------------------------------------
    //  AIM Symbology ID characters
    //-----------------------------------------------------------------------------
    #define AIMID_AZTEC         'z'
    #define AIMID_CODABAR       'F'
    #define AIMID_CODE11        'H'
    #define AIMID_CODE128       'C'
    #define AIMID_CODE39        'A'
    #define AIMID_CODE49        'T'
    #define AIMID_CODE93        'G'
    #define AIMID_GS1_COMPOSITE 'e'
    #define AIMID_DATAMATRIX    'd'
    #define AIMID_EAN           'E'
    #define AIMID_INT25         'I'
    #define AIMID_MAXICODE      'U'
    #define AIMID_MICROPDF      'L'
    #define AIMID_PDF417        'L'
    #define AIMID_OCR           'o'
    #define AIMID_QR            'Q'
    #define AIMID_GS1_DATABAR   'e'
    #define AIMID_UPC           'E'
    #define AIMID_POSTNET       'X'
    #define AIMID_ISBT          'C'
    #define AIMID_BPO           'X'
    #define AIMID_CANPOST       'X'
    #define AIMID_AUSPOST       'X'
    #define AIMID_IATA25        'R'
    #define AIMID_CODABLOCK     'O'
    #define AIMID_JAPOST        'X'
    #define AIMID_PLANET        'X'
    #define AIMID_DUTCHPOST     'X'
    #define AIMID_MSI           'M'
    #define AIMID_TLC39         'L'
    #define AIMID_MATRIX25      'X'
    #define AIMID_KORPOST       'X'
    #define AIMID_TRIOPTIC      'X'
    #define AIMID_CODE32        'X'
    #define AIMID_STRT25        'S'
    #define AIMID_PLESSEY       'P'
    #define AIMID_CHINAPOST     'X'
    #define AIMID_TELEPEN       'B'
    #define AIMID_CODE16K       'K'
    #define AIMID_POSICODE      'p'
    #define AIMID_GS1_128       'E'
    #define AIMID_UPUIDTAG      'X'
    #define AIMID_CODE4CB       'X'
    #define AIMID_COMPOSITE     AIMID_GS1_COMPOSITE
    #define AIMID_COUPONCODE    AIMID_GS1_128
    #define AIMID_RSS           AIMID_GS1_DATABAR

    //-----------------------------------------------------------------------------
    //  HHP Symbology ID characters
    //-----------------------------------------------------------------------------
    #define SYMID_AZTEC         'z'
    #define SYMID_CODABAR       'a'
    #define SYMID_CODE11        'h'
    #define SYMID_CODE128       'j'
    #define SYMID_CODE39        'b'
    #define SYMID_CODE49        'l'
    #define SYMID_CODE93        'i'
    #define SYMID_GS1_COMPOSITE 'y'
    #define SYMID_DATAMATRIX    'w'
    #define SYMID_EAN           'd'
    #define SYMID_INT25         'e'
    #define SYMID_MAXICODE      'x'
    #define SYMID_MICROPDF      'R'
    #define SYMID_PDF417        'r'
    #define SYMID_POSTNET       'P'
    #define SYMID_OCR           'O'
    #define SYMID_QR            's'
    #define SYMID_GS1_DATABAR   'y'
    #define SYMID_UPC           'c'
    #define SYMID_ISBT          'j'
    #define SYMID_BPO           'B'
    #define SYMID_CANPOST       'C'
    #define SYMID_AUSPOST       'A'
    #define SYMID_IATA25        'f'
    #define SYMID_CODABLOCK     'q'
    #define SYMID_JAPOST        'J'
    #define SYMID_PLANET        'L'
    #define SYMID_DUTCHPOST     'K'
    #define SYMID_MSI           'g'
    #define SYMID_TLC39         'T'
    #define SYMID_MATRIX25      'm'
    #define SYMID_KORPOST       '?'
    #define SYMID_TRIOPTIC      '='
    #define SYMID_CODE32        '<'
    #define SYMID_STRT25        'f'
    #define SYMID_PLESSEY       'n'
    #define SYMID_CHINAPOST     'Q'
    #define SYMID_TELEPEN       't'
    #define SYMID_CODE16K       'o'
    #define SYMID_POSICODE      'W'
    #define SYMID_GS1_128       'c'
    #define SYMID_UPUIDTAG      'N'
    #define SYMID_CODE4CB       'M'
    #define SYMID_COMPOSITE     SYMID_GS1_COMPOSITE
    #define SYMID_COUPONCODE    SYMID_GS1_128
    #define SYMID_RSS           SYMID_GS1_DATABAR
	//-----------------------------------------------------------------------------
    //  Supported OCR Fonts
    //-----------------------------------------------------------------------------
    typedef enum
    {
        OCR_DISABLED = 0,
        OCR_A,
        OCR_B,
        OCR_MONEY,
        OCR_MICR_UNSUPPORTED,

    } OCRMode_t;
    //-----------------------------------------------------------------------------
    // OCR directions
    //-----------------------------------------------------------------------------
    typedef enum
    {
        LeftToRight = 0,
        TopToBottom,
        RightToLeft,
        BottomToTop,

    } OCRDirection_t;
    // Decoder configuration definitions for each symbology
    #define SYMBOLOGY_ENABLE                0x00000001  // Enable Symbology bit
    #define SYMBOLOGY_CHECK_ENABLE          0x00000002  // Enable usage of check character
    #define SYMBOLOGY_CHECK_TRANSMIT        0x00000004  // Send check character
    #define SYMBOLOGY_START_STOP_XMIT       0x00000008  // Include the start and stop characters in the decoded result string
    #define SYMBOLOGY_ENABLE_APPEND_MODE    0x00000010  // Code39 append mode
    #define SYMBOLOGY_ENABLE_FULLASCII      0x00000020  // Enable Code39 Full ASCII
    #define SYMBOLOGY_NUM_SYS_TRANSMIT      0x00000040  // UPC-A/UPC-e Send Num Sys
    #define SYMBOLOGY_2_DIGIT_ADDENDA       0x00000080  // Enable 2 digit Addenda (UPC & EAN)
    #define SYMBOLOGY_5_DIGIT_ADDENDA       0x00000100  // Enable 5 digit Addenda (UPC & EAN)
    #define SYMBOLOGY_ADDENDA_REQUIRED      0x00000200  // Only allow codes with addenda (UPC & EAN)
    #define SYMBOLOGY_ADDENDA_SEPARATOR     0x00000400  // Include Addenda separator space in returned string.
    #define SYMBOLOGY_EXPANDED_UPCE         0x00000800  // Extended UPC-E
    #define SYMBOLOGY_UPCE1_ENABLE          0x00001000  // UPC-E1 enable (use SYMBOLOGY_ENABLE for UPC-E0)
    #define SYMBOLOGY_COMPOSITE_UPC         0x00002000  // Enable UPC composite codes
    #define SYMBOLOGY_AZTEC_RUNE            0x00004000  // Enable Aztec Run
    #define SYMBOLOGY_AUSTRALIAN_BAR_WIDTH  0x00010000  // Include australian postal bar data in string
    #define SYMBOLOGY_AUS_CUST_FIELD_NUM    0x00020000  // Customer fields as numeric data using the N Table.
    #define SYMBOLOGY_AUS_CUST_FIELD_AlPHA  0x00040000  // Customer fields as alphanumeric data using the C Table.
    // For GS1 DataBar there is only one symbology ID so we use 3 flags for enable
    #define SYMBOLOGY_GS1_EXPANDED_ENABLE   0x00800000  // Enable RSE Symbology bit
    #define SYMBOLOGY_GS1_LIMITED_ENABLE    0x01000000  // Enable RSL Symbology bit
    #define SYMBOLOGY_GS1_OMNI_ENABLE       0x02000000  // Enable RSS Symbology bit
    #define SYMBOLOGY_GS1_STACKED_ENABLE    SYMBOLOGY_GS1_OMNI_ENABLE
    #define SYMBOLOGY_GS1X_ENABLE_MASK      0x03800000
    #define SYMBOLOGY_RSE_ENABLE            SYMBOLOGY_GS1_EXPANDED_ENABLE
    #define SYMBOLOGY_RSL_ENABLE            SYMBOLOGY_GS1_LIMITED_ENABLE
    #define SYMBOLOGY_RSS_ENABLE            SYMBOLOGY_GS1_STACKED_ENABLE
    #define SYMBOLOGY_RSX_ENABLE_MASK       SYMBOLOGY_GS1X_ENABLE_MASK
    // Telepen and PosiCode
    #define SYMBOLOGY_TELEPEN_OLD_STYLE     0x04000000  // Telepen Old Style mode.
    #define SYMBOLOGY_POSICODE_LIMITED_1    0x08000000  // PosiCode Limited of 1
    #define SYMBOLOGY_POSICODE_LIMITED_2    0x10000000  // PosiCode Limited of 2
    #define SYMBOLOGY_CODABAR_CONCATENATE   0x20000000  // Codabar concatenate.
    // For OCR we reuse flags since none of the other flags apply to OCR
    #define SYMBOLOGY_ENABLE_OCR_A          0x00000001  // OCR-A enable.
    #define SYMBOLOGY_ENABLE_OCR_B          0x00000002  // OCR-B enable.
    #define SYMBOLOGY_ENABLE_OCR_MONEY      0x00000004  // OCR-Money enable.
    #define SYMBOLOGY_ENABLE_OCR_MICR       0x00000008  // OCR-Micr enable.

    // Symbology structure set masks
    #define SYM_MASK_FLAGS                  0x00000001  // Flags are valid
    #define SYM_MASK_MIN_LEN                0x00000002  // Min Length valid
    #define SYM_MASK_MAX_LEN                0x00000004  // Max Length valid
    #define SYM_MASK_OCR_MODE               0x00000008  // OCR mode valid
    #define SYM_MASK_DIRECTION              0x00000010  // OCR direction valid.
    #define SYM_MASK_TEMPLATE               0x00000020  // OCR template valid.
    #define SYM_MASK_GROUP_H                0x00000040  // OCR group H valid.
    #define SYM_MASK_GROUP_G                0x00000080  // OCR group H valid.
    #define SYM_MASK_CHECK_CHAR             0x00000100  // OCR check char valid.
    #define SYM_MASK_ALL                    0xffffffff

    // Structure for symbologies with no specified min or max length.
    typedef struct _tagSymFlagsOnly
    {
        DWORD   dwStructSize;                           // Set to sizeof( SymFlagsOnly_t );
        DWORD   dwMask;
        DWORD   dwFlags;

    } SymFlagsOnly_t, *PSymFlagsOnly_t;

    // Structure for symbologies with min & max length.
    typedef struct _tagSymFlagsRange
    {
        DWORD   dwStructSize;                           // Set to sizeof( SymFlagsRange_t );
        DWORD   dwMask;
        DWORD   dwFlags;
        DWORD   dwMinLen;
        DWORD   dwMaxLen;

    } SymFlagsRange_t, *PSymFlagsRange_t;

    // Structure for oddball OCR
    #define MAX_TEMPLATE_LEN            256
    #define MAX_GROUP_LEN               256
    #define MAX_CHECK_CHAR_LEN          64
    #define MAX_GROUP_H_LEN             MAX_GROUP_LEN
    #define MAX_GROUP_G_LEN             MAX_GROUP_LEN
    typedef struct _tagSymCodeOCR
    {
        DWORD           dwStructSize;                   // Set to sizeof( SymCodeOcr_t );
        DWORD           dwMask;
        OCRMode_t       ocrMode;
        OCRDirection_t  ocrDirection;
        TCHAR           tcTemplate[ MAX_TEMPLATE_LEN ];
        TCHAR           tcGroupG[ MAX_GROUP_LEN ];
        TCHAR           tcGroupH[ MAX_GROUP_LEN ];
        TCHAR           tcCheckChar[ MAX_CHECK_CHAR_LEN ];

    } SymCodeOCR_t, *PSymCodeOCR_t;

    // Define aliases for each symbology structure
    #define AZTEC_T         SymFlagsRange_t
    #define CODABAR_T       SymFlagsRange_t
    #define CODE11_T        SymFlagsRange_t
    #define CODE128_T       SymFlagsRange_t
    #define CODE39_T        SymFlagsRange_t
    #define CODE49_T        SymFlagsRange_t
    #define CODE93_T        SymFlagsRange_t
    #define COMPOSITE_T     SymFlagsRange_t
    #define DATAMATRIX_T    SymFlagsRange_t
    #define EAN8_T          SymFlagsOnly_t
    #define EAN13_T         SymFlagsOnly_t
    #define INT25_T         SymFlagsRange_t
    #define MAXICODE_T      SymFlagsRange_t
    #define MICROPDF_T      SymFlagsRange_t
    #define OCR_T           SymCodeOCR_t
    #define PDF417_T        SymFlagsRange_t
    #define POSTNET_T       SymFlagsOnly_t
    #define QR_T            SymFlagsRange_t
    #define GS1_DATABAR_T   SymFlagsRange_t
    #define UPCA_T          SymFlagsOnly_t
    #define UPCE_T          SymFlagsOnly_t
    #define ISBT_T          SymFlagsOnly_t
    #define BPO_T           SymFlagsOnly_t
    #define CANPOST_T       SymFlagsOnly_t
    #define AUSPOST_T       SymFlagsOnly_t
    #define IATA25_T        SymFlagsRange_t
    #define CODABLOCK_T     SymFlagsRange_t
    #define JAPOST_T        SymFlagsOnly_t
    #define PLANET_T        SymFlagsOnly_t
    #define DUTCHPOST_T     SymFlagsOnly_t
    #define MSI_T           SymFlagsRange_t
    #define TLCODE39_T      SymFlagsOnly_t
    #define MATRIX25_T      SymFlagsRange_t
    #define KORPOST_T       SymFlagsRange_t
    #define TRIOPTIC_T      SymFlagsOnly_t
    #define CODE32_T        SymFlagsOnly_t
    #define CODE25_T        SymFlagsRange_t
    #define PLESSEY_T       SymFlagsRange_t
    #define CHINAPOST_T     SymFlagsRange_t
    #define TELEPEN_T       SymFlagsRange_t
    #define CODE16K_T       SymFlagsRange_t
    #define POSICODE_T      SymFlagsRange_t
    #define GS1_128_T       SymFlagsOnly_t
    #define UPUIDTAG_T      SymFlagsOnly_t
    #define CODE4CB_T       SymFlagsOnly_t

    // Structure of structures, one for each symbology.
    typedef struct _tagSymCfg_t
    {
        DWORD           dwStructSize;   // Set to sizeof( SymCfg_t );
        // Linear Codes                 // Flags supported for this code
        //---------------------------------------------------------------
        CODABAR_T       codabar;        // Enable,Check,CheckSend,StartStop,Concatenate
        CODE11_T        code11;         // Enable,Check,CheckSend
        CODE128_T       code128;        // Enable
        CODE39_T        code39;         // Enable,Check,CheckSend,StartStop,Append,FullAscii
        CODE49_T        code49;         // Enable
        CODE93_T        code93;         // Enable
        COMPOSITE_T     composite;      // Enable,CompositeUPC
        DATAMATRIX_T    datamatrix;     // Enable
        EAN8_T          ean8;           // Enable,Check,Addenda2,Addenda5,AddendaReq,AddendaSep
        EAN13_T         ean13;          // Enable,Check,Addenda2,Addenda5,AddendaReq,AddendaSep
        IATA25_T        iata25;         // Enable
        INT25_T         int2of5;        // Enable,Check,CheckSend
        ISBT_T          isbt;           // Enable
        MSI_T           msi;            // Enable,Check
        UPCA_T          upcA;           // Enable,check,NumSysTrans,Addenda2,Addenda5,AddendaReq,AddendaSep
        UPCE_T          upcE;           // Enable,check,NumSysTrans,Addenda2,Addenda5,AddendaReq,AddendaSep,ExpandedE,EnableE1
        // Postal Codes
        AUSPOST_T       australiaPost;  // Enable,AustralianBar
        BPO_T           britishPost;    // Enable
        CANPOST_T       canadaPost;     // Enable
        DUTCHPOST_T     dutchPost;      // Enable
        JAPOST_T        japanPost;      // Enable
        PLANET_T        usPlanet;       // Enable,Check
        POSTNET_T       usPostnet;      // Enable,Check
        // 2D Codes
        AZTEC_T         aztec;          // Enable,AztecRune
        CODABLOCK_T     codablock;      // Enable
        MAXICODE_T      maxicode;       // Enable,SCMOnly
        MICROPDF_T      microPDF;       // Enable
        PDF417_T        pdf417;         // Enable
        QR_T            qr;             // Enable
        GS1_DATABAR_T   gs1_databar;    // Enable (RSS,RSL,RSE)
        TLCODE39_T      tlCode39;       // Enable
        // Special OCR "code"
        OCR_T           ocr;            // None (See SymCodeOCR_t)
        // New codes
        MATRIX25_T      matrix25;       // Enable,
        KORPOST_T       koreaPost;      // Enable
        TRIOPTIC_T      triopticCode;   // Enable
        CODE32_T        code32;         // Enable
        CODE25_T        code2of5;       // Enable
        PLESSEY_T       plesseyCode;    // Enable
        CHINAPOST_T     chinaPost;      // Enable
        TELEPEN_T       telepen;        // Enable,OldStyle?
        CODE16K_T       code16k;        // Enable
        POSICODE_T      posiCode;       // Enable,Limited 1 and 2
        GS1_128_T       gs1_128;        // Enable
        // 5000 engine only codes?
        UPUIDTAG_T      upuIdTag;       // Enable
        CODE4CB_T       code4CB;        // Enable

    } SymCfg_t, HHI_SYM_CONFIG, *PSymCfg_t, *PHHI_SYM_CONFIG;

#endif

// $Log: hhiSymCfg.h  $
// Revision 1.5 2008/06/08 15:51:04EDT MontoroJ 
// - Changed name of GS1 DataBlock Stacked Enable flag to GS1 DataBlock Omni Enable (old 
//   flag is defined as new flag for backward compatability).
// Revision 1.4 2008/05/21 16:28:08EDT MontoroJ 
// - Renamed RSS -> GS1_DATABAR, COMPOSITE -> GS1_COMPOSITE and COUPONCODE ->
//   GS1_128.
// Revision 1.3 2008/05/15 12:28:01EDT MontoroJ 
// - Removed AztecMesa entirely. Bugzilla #4479
// - Fixed issue with reading the symbology min/max range. The SDK was just reading the min value
//   range which should be the same as the max. However, I have found a couple of instances where
//   the firmware is screwed up so the code has been changed to return the min value range low 
//   and the max value range high.  This way setting the symbol range values won't fail as long as the
//   user keeps the values within the returned limit.
// Revision 1.2 2007/07/18 12:23:55EDT MontoroJ 
// - Cleaned up some of the naming convention issues with some of the structures and masks.
// Revision 1.2 2007/02/28 15:52:43EST MontoroJ 
// - Updated the module header information (specifically the copyright)
// Revision 1.10 2005/08/31 08:16:09EDT MontoroJ 
// - Fixed  OCR (both AIM and HHP) and Datamatrix (HHP) symbol characters.
// Revision 1.9 2005/06/27 15:02:38EDT MontoroJ 
// - Added symbol flags for Australian Post for Customer Field Interpretation.
// Revision 1.8 2005/04/05 15:14:49EDT MontoroJ 
// - Added USPS 4 state code and 4 state Id Tag codes.
// Revision 1.7 2004/12/17 11:52:37EST montoroj 
// - Added the concatenate flag to the comments for codabar amoung other changes to comments.
// Revision 1.6 2004/09/16 10:01:28EDT montoroj 
// - Added a mask define for Codabar Concatenate flag.
// Revision 1.5 2004/07/27 14:26:19EDT montoroj
// - Added defines and symbology structure members for the following symbologies:
//   Trioptic, Telepen, Code32, Coupon Code, PosiCode, Plessey Code, Straight 2 of 5, China
//   Post and Code 16K.
// Revision 1.4 2004/01/06 14:23:21EST holzhaud
// Added '#define's for Korean Postal code support.
// Revision 1.3 2003/07/07 13:05:23EDT holzhaud
// Removed "MAXSCM".
// Revision 1.2 2003/06/22 21:40:59EDT holzhaud
// comments only.
// Revision 1.1 2003/06/19 11:54:30EDT holzhaud
// Initial revision
// Member added to project d:/MKS_IT/SDK/Matrix_SDK_Examples/Matrix_SDK_Examples.pj
// Revision 1.1 2003/05/15 10:46:30EDT montoroj
// Initial revision
// Member added to project d:/MKS_IT/SDK/Matrix_SDK/Matrix_SDK.pj
// Revision 1.5 2003/04/02 16:19:52EST montoroj
// - Add SYM_ALL to symbologies list (it comes after NUM_SYMBOLOGIES and has a
//   value of 100)
// Revision 1.4 2003/03/04 16:34:25EST montoroj
// - Added defines and structure to support Matrix 2 of 5 code.
// Revision 1.3 2003/02/20 16:32:52EST montoroj
// - Replaced $LOG$ with $Log: hhiSymCfg.h  $
// - Replaced Revision 1.5 2008/06/08 15:51:04EDT MontoroJ 
// - Replaced - Changed name of GS1 DataBlock Stacked Enable flag to GS1 DataBlock Omni Enable (old 
// - Replaced   flag is defined as new flag for backward compatability).
// - Replaced Revision 1.4 2008/05/21 16:28:08EDT MontoroJ 
// - Replaced - Renamed RSS -> GS1_DATABAR, COMPOSITE -> GS1_COMPOSITE and COUPONCODE ->
// - Replaced   GS1_128.
// - Replaced Revision 1.3 2008/05/15 12:28:01EDT MontoroJ 
// - Replaced - Removed AztecMesa entirely. Bugzilla #4479
// - Replaced - Fixed issue with reading the symbology min/max range. The SDK was just reading the min value
// - Replaced   range which should be the same as the max. However, I have found a couple of instances where
// - Replaced   the firmware is screwed up so the code has been changed to return the min value range low 
// - Replaced   and the max value range high.  This way setting the symbol range values won't fail as long as the
// - Replaced   user keeps the values within the returned limit.
// - Replaced Revision 1.2 2007/07/18 12:23:55EDT MontoroJ 
// - Replaced - Cleaned up some of the naming convention issues with some of the structures and masks.
// - Replaced Revision 1.2 2007/02/28 15:52:43EST MontoroJ 
// - Replaced - Updated the module header information (specifically the copyright)
// - Replaced Revision 1.10 2005/08/31 08:16:09EDT MontoroJ 
// - Replaced - Fixed  OCR (both AIM and HHP) and Datamatrix (HHP) symbol characters.
// - Replaced Revision 1.9 2005/06/27 15:02:38EDT MontoroJ 
// - Replaced - Added symbol flags for Australian Post for Customer Field Interpretation.
// - Replaced Revision 1.8 2005/04/05 15:14:49EDT MontoroJ 
// - Replaced - Added USPS 4 state code and 4 state Id Tag codes.
// - Replaced Revision 1.7 2004/12/17 11:52:37EST montoroj 
// - Replaced - Added the concatenate flag to the comments for codabar amoung other changes to comments.
// - Replaced Revision 1.6 2004/09/16 10:01:28EDT montoroj 
// - Replaced - Added a mask define for Codabar Concatenate flag.
// - Replaced Revision 1.5 2004/07/27 14:26:19EDT montoroj
// - Replaced - Added defines and symbology structure members for the following symbologies:
// - Replaced   Trioptic, Telepen, Code32, Coupon Code, PosiCode, Plessey Code, Straight 2 of 5, China
// - Replaced   Post and Code 16K.
// - Replaced Revision 1.4 2004/01/06 14:23:21EST holzhaud
// - Replaced Added '#define's for Korean Postal code support.
// - Replaced Revision 1.3 2003/07/07 13:05:23EDT holzhaud
// - Replaced Removed "MAXSCM".
// - Replaced Revision 1.2 2003/06/22 21:40:59EDT holzhaud
// - Replaced comments only.
// - Replaced Revision 1.1 2003/06/19 11:54:30EDT holzhaud
// - Replaced Initial revision
// - Replaced Member added to project d:/MKS_IT/SDK/Matrix_SDK_Examples/Matrix_SDK_Examples.pj
// - Replaced Revision 1.1 2003/05/15 10:46:30EDT montoroj
// - Replaced Initial revision
// - Replaced Member added to project d:/MKS_IT/SDK/Matrix_SDK/Matrix_SDK.pj
// - Replaced Revision 1.5 2003/04/02 16:19:52EST montoroj
// - Replaced - Add SYM_ALL to symbologies list (it comes after NUM_SYMBOLOGIES and has a
// - Replaced   value of 100)
// - Replaced Revision 1.4 2003/03/04 16:34:25EST montoroj
// - Replaced - Added defines and structure to support Matrix 2 of 5 code.
