/*
******************************************************************************
*
*   UNLESS OTHER WISE AGREED TO BY HONEYWELL INTERNATIONAL AND THE USER 
*   OF THIS CODE, THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT 
*   WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT 
*   LIMITED TO 	THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS 
*   FOR A 	PARTICULAR PURPOSE.
*   
*   COPYRIGHT (C) 2000-2008 HONEYWELL INTERNALTIONAL, Inc.
*   
*   THIS SOFTWARE IS PROTECTED BY COPYRIGHT LAWS OF THE UNITED STATES OF 
*   AMERICA AND OF FOREIGN COUNTRIES. THIS SOFTWARE IS FURNISHED UNDER A 
*   LICENSE AND/OR A NONDISCLOSURE AGREEMENT AND MAY BE USED IN ACCORDANCE 
*   WITH THE TERMS OF THOSE	AGREEMENTS. UNAUTHORIZED REPRODUCTION, 
*   DUPLICATION OR DISTRIBUTION OF THIS SOFTWARE, OR ANY PORTION OF IT 
*   WILL BE PROSECUTED TO THE MAXIMUM EXTENT POSSIBLE UNDER THE LAW.
*
******************************************************************************
*
* $RCSfile: IQ_Imaging_Sample_MFC/IQ_Imaging_Sample_MFC_Settings_Dlg.cpp $
* $Revision: 1.2 $
* $Date: 2009/09/21 09:13:55EDT $
* $Author: Haile, Adam Michael (E412723) $
*
*  File:        Intelimgdlg.cpp
*
*  Description: Class methods for handling the intelligent imaging setup dialog.
*
*  Functions:   Public Interface
*               ----------------
*               CIntelImgDlg::SetIntelImgStruct()
*               CIntelImgDlg::GetIntelImgStruct()
*
*               Protected Virtual Overrides
*               ---------------------------
*               CIntelImgDlg::OnInitDialog()
*               CIntelImgDlg::OnCancel()
*               CIntelImgDlg::OnOK()
*               CIntelImgDlg::OnClose()
*
*               Protected Interface
*               -------------------
*               CIntelImgDlg::OnChangeIntelimgItem()
*               CIntelImgDlg::OnIntelimgApply()
*               CIntelImgDlg::OnAztecValues()
*               CIntelImgDlg::OnCode39Values()
*
*               Private Interface
*               -----------------
*               CIntelImgDlg::ReadControlValues()
*               CIntelImgDlg::ItemsChanged()
*
*  Rev. Date    By     Revision Notes
*  ----------   ---    ----------------
*  08/19/2002   JCM    Original Release
*  03/06/2003   JCM    bSendBinary added to HHI_INTEL_IMG structure. Item added
*                      to dialog (checkbox).  Code added to support new control.
*  05/19/2003   JCM    Plugged hole where it was possible to quit dialog with 
*                      invalid data if you really wanted to.
*
******************************************************************************
*/

// IntelImgDlg.cpp : implementation file
//
#include "stdafx.h"
#include "resource.h"
#include "IQ_Imaging_Sample_MFC_Settings_Dlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

// Code39 Intelligent Imaging (Skaneateles Demo Sheet)
#define INTELIMG_C39_ASPECT_RATIO   33
#define INTELIMG_C39_X_OFFSET       -2
#define INTELIMG_C39_Y_OFFSET       53
#define INTELIMG_C39_HEIGHT         56
#define INTELIMG_C39_WIDTH          180
// Aztec Intelligent Imaging (Charlotte Demo Sheet)
#define INTELIMG_AZTEC_ASPECT_RATIO 1
#define INTELIMG_AZTEC_X_OFFSET     2
#define INTELIMG_AZTEC_Y_OFFSET     44
#define INTELIMG_AZTEC_HEIGHT       58
#define INTELIMG_AZTEC_WIDTH        124

/////////////////////////////////////////////////////////////////////////////
// CIntelImgDlg dialog

CIntelImgDlg::CIntelImgDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CIntelImgDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CIntelImgDlg)
	m_uAspectRatio = 0;
	m_uHeight = 0;
	m_uWidth = 0;
	m_nOffsetX = 0;
	m_nOffsetY = 0;
	m_bBinaryImage = FALSE;
	//}}AFX_DATA_INIT
    m_intelImg.dwStructSize = sizeof( HHI_INTEL_IMG );
    m_intelImg.dwHeight = INTELIMG_C39_HEIGHT;
    m_intelImg.dwWidth = INTELIMG_C39_WIDTH;
    m_intelImg.dwAspectRatio = INTELIMG_C39_ASPECT_RATIO;
    m_intelImg.nOffsetX = INTELIMG_C39_X_OFFSET;
    m_intelImg.nOffsetY = INTELIMG_C39_Y_OFFSET;
    m_intelImg.bSendBinary = FALSE;
    m_bApplied = FALSE;
    m_bInitialized = FALSE;
    m_bChangesValid = TRUE;
}
// End CIntelImgDlg()

void CIntelImgDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CIntelImgDlg)
	DDX_Control(pDX, IDC_INTELIMG_YOFF_SPIN, m_offsetYSpin);
	DDX_Control(pDX, IDC_INTELIMG_XOFF_SPIN, m_offsetXSpin);
	DDX_Control(pDX, IDC_INTELIMG_WIDTH_SPIN, m_widthSpin);
	DDX_Control(pDX, IDC_INTELIMG_HEIGHT_SPIN, m_heightSpin);
	DDX_Control(pDX, IDC_INTELIMG_ASPECT_RATIO_SPIN, m_aspectRatioSpin);
	DDX_Text(pDX, IDC_INTELIMG_ASPECT_RATIO, m_uAspectRatio);
	DDV_MinMaxUInt(pDX, m_uAspectRatio, 1, 999);
	DDX_Text(pDX, IDC_INTELIMG_HEIGHT, m_uHeight);
	DDX_Text(pDX, IDC_INTELIMG_WIDTH, m_uWidth);
	DDX_Text(pDX, IDC_INTELIMG_XOFF, m_nOffsetX);
	DDX_Text(pDX, IDC_INTELIMG_YOFF, m_nOffsetY);
	DDX_Check(pDX, IDC_INTELIMG_BINARY, m_bBinaryImage);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CIntelImgDlg, CDialog)
	//{{AFX_MSG_MAP(CIntelImgDlg)
	ON_BN_CLICKED(IDC_INTELIMG_APPLY, OnIntelimgApply)
	ON_WM_CLOSE()
	ON_BN_CLICKED(IDC_AZTEC_VALUES, OnAztecValues)
	ON_BN_CLICKED(IDC_CODE39_VALUES, OnCode39Values)
	ON_EN_CHANGE(IDC_INTELIMG_ASPECT_RATIO, OnChangeIntelimgItem)
	ON_EN_CHANGE(IDC_INTELIMG_HEIGHT, OnChangeIntelimgItem)
	ON_EN_CHANGE(IDC_INTELIMG_WIDTH, OnChangeIntelimgItem)
	ON_EN_CHANGE(IDC_INTELIMG_XOFF, OnChangeIntelimgItem)
	ON_EN_CHANGE(IDC_INTELIMG_YOFF, OnChangeIntelimgItem)
	ON_BN_CLICKED(IDC_INTELIMG_BINARY, OnChangeIntelimgItem)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/*
******************************************************************************
*
*                      Public Methods
*
******************************************************************************
*/

/*
******************************************************************************
*
*  Name:        CIntelImgDlg::SetIntelImgStruct()
*
*  Description: Used to set the intial values of this dialog.
*
*  Parameters:  PHHI_INTEL_IMG pIntelImg; (I) // Pointer to struct with data
*                                             // with which to initialize the
*                                             // class member m_intelImg.
*
*  Returns:     TRUE  - If member structure initialized.
*               FALSE - If pIntelImg not a valid structure pointer.
*
*  Rev. Date    By    Revision Notes
*  ----------   ---   ----------------
*  01/13/2003   JCM   Original Release
*
******************************************************************************
*/

BOOL CIntelImgDlg::SetIntelImgStruct( PHHI_INTEL_IMG pIntelImg )
{
    // Copy the intelligent image info into member structure.
    ::memcpy( &m_intelImg,pIntelImg,sizeof( HHI_INTEL_IMG ) );

    return( TRUE );
}
// End SetIntelImgStruct()

/*
******************************************************************************
*
*  Name:        CIntelImgDlg::GetIntelImgStruct()
*
*  Description:
*
*  Parameters:  PHHI_INTEL_IMG pIntelImg; (I) // Pointer to struct where member
*                                             // struct data is to be stored.
*
*  Returns:     TRUE  - If member structure copied to user buffer.
*               FALSE - If pIntelImg not a valid structure pointer.
*
*  Rev. Date    By    Revision Notes
*  ----------   ---   ----------------
*  01/13/2003   JCM   Original Release
*
******************************************************************************
*/

BOOL CIntelImgDlg::GetIntelImgStruct( PHHI_INTEL_IMG pIntelImg )
{
    // Validate pointer then structure by size.
    // Copy member values to caller buffer.
    ::memcpy( pIntelImg,&m_intelImg,sizeof( HHI_INTEL_IMG ) );

    return( TRUE );
}
// End GetIntelImgStruct()

/*
******************************************************************************
*
*                     Protected Virtual Overrides
*
******************************************************************************
*/

/*
******************************************************************************
*
*  Name:        CIntelImgDlg::OnInitDialog()
*
*  Description: Method called by framework when dialog is intialized. After
*               call to base class OnInitDialog() the dialog controls can be
*               accessed safely.  This is where we initialize control values,
*               set spinbox ranges and disable the apply button.
*
*  Parameters:  None.
*
*  Returns:     TRUE.
*
*  Rev. Date    By    Revision Notes
*  ----------   ---   ----------------
*  01/13/2003   JCM   Original Release
*  03/06/2003   JCM   Added setting of m_bBinaryImage from HHI_INTEL_IMG struct
*                     SendBinary added recently.
*
******************************************************************************
*/

BOOL CIntelImgDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	GetDlgItem( IDC_BAR_WIDTH_STATIC )->SetWindowPos( &wndBottom,0,0,0,0,SWP_NOMOVE | SWP_NOSIZE );
    // Set ranges so the arrows make sense.
    m_aspectRatioSpin.SetRange32( 0,1000 );
    m_widthSpin.SetRange32( 0,1000 );
    m_heightSpin.SetRange32( 0,1000 );
    m_offsetXSpin.SetRange32( -1000,1000 );
    m_offsetYSpin.SetRange32( -1000,1000 );
    // Initialize edit/spin values
    m_uAspectRatio = m_intelImg.dwAspectRatio;
	m_uHeight = m_intelImg.dwHeight;
	m_uWidth = m_intelImg.dwWidth;
	m_nOffsetX = m_intelImg.nOffsetX;
	m_nOffsetY = m_intelImg.nOffsetY;
    m_bBinaryImage = m_intelImg.bSendBinary;
    // Set to dialog
    UpdateData( FALSE );
    // Everything is ready.
    m_bInitialized = TRUE;
    // Update Code39, Aztec and Apply button states
    UpdateButtonStates();

#ifdef _WIN32_WCE
    // Fill Screen for non pocketPC's
    #ifndef WIN32_PLATFORM_PSPC
        RECT    rect;
        GetParent()->GetClientRect( &rect );
        SetWindowPos( NULL,0,0,(rect.right-rect.left),(rect.bottom-rect.top),SWP_NOZORDER );
    #endif
#endif

	return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}
// End OnInitDialog()

/*
******************************************************************************
*
*  Name:        CIntelImgDlg::OnCancel()
*
*  Description: Method called when Esc key pressed (Win32 only - not WinCE).
*
*  Parameters:  Method acts like a cancel unless user has saved values then it
*               acts like an OnOK().  This means the code that called DoModal()
*               can use the return value of IDOK to know if it needs to retrieve
*               changed values from this class.
*
*  Returns:     None.
*
*  Rev. Date    By    Revision Notes
*  ----------   ---   ----------------
*  01/13/2003   JCM   Original Release
*
******************************************************************************
*/

void CIntelImgDlg::OnCancel()
{
    if( !m_bApplied )
        CDialog::OnCancel();
    else
        CDialog::OnOK();
}
// End OnCancel()

/*
******************************************************************************
*
*  Name:        CIntelImgDlg::OnOK()
*
*  Description: Called when OK button selected (Only visible in WinCE). Checks
*               to see if any values have changed from "current copy in m_intelImg"
*               If so, prompts user if save changes (yes,no or cancel.  If save,
*               values are stored in m_intelImg and base class OnOK is called. If
*               no, base class OnCancel() is called.  If cancel, then the dialog
*               continues.
*
*  Parameters:  None.
*
*  Returns:     None.
*
*  Rev. Date    By    Revision Notes
*  ----------   ---   ----------------
*  01/13/2003   JCM   Original Release
*
******************************************************************************
*/

void CIntelImgDlg::OnOK()
{
    int     nRetVal = IDNO;     // Return value from message box.

    if( ItemsChanged() )
    {
        if( m_bChangesValid )
        {
            if( (nRetVal = AfxMessageBox( _T("Save Changes?"),MB_YESNOCANCEL | MB_ICONQUESTION,0 )) == IDYES )
                OnIntelimgApply();
            else if( (nRetVal == IDNO) && !m_bApplied )
                CDialog::OnCancel();
        }
        else
            nRetVal = IDCANCEL;
    }
    // If not canceling, call base class OnOK()
    if( nRetVal != IDCANCEL )
        CDialog::OnOK();
}
// End OnOK()

/*
******************************************************************************
*
*  Name:        CIntelImgDlg::OnClose()
*
*  Description: This method calls OnOK(). It is called when user selects upper
*               left corner x of dialog (Win32 only)
*
*  Parameters:  None.
*
*  Returns:     None.
*
*  Rev. Date    By    Revision Notes
*  ----------   ---   ----------------
*  01/13/2003   JCM   Original Release
*
******************************************************************************
*/

void CIntelImgDlg::OnClose()
{
    OnOK();
}
// End OnClose()

/*
******************************************************************************
*
*                   Dialog Control Method Callbacks
*
******************************************************************************
*/

/*
******************************************************************************
*
*  Name:        CIntelImgDlg::OnChangeIntelimgItem()
*
*  Description: Method called whenever any of the dialogs edit box values is
*               changed.  It calls ItemsChanged() to know if it needs to enable
*               or disable the Apply button (enable if changed, disable if not)
*
*  Parameters:  None.
*
*  Returns:     None.
*
*  Rev. Date    By    Revision Notes
*  ----------   ---   ----------------
*  01/13/2003   JCM   Original Release
*
******************************************************************************
*/

void CIntelImgDlg::OnChangeIntelimgItem()
{
    // Make sure dialog controls are intialized then enable/disable apply button
    // based on whether any of the control values differs from m_intelImg.
    if( m_bInitialized )
        UpdateButtonStates();
    return;
}
// End OnChangeIntelimgItem()

/*
******************************************************************************
*
*  Name:        CIntelImgDlg::OnIntelimgApply()
*
*  Description: Method called when apply button selected.  Copies the current
*               control values into m_intelImg, disables the apply button and
*               sets the m_bApplied flag.
*
*  Parameters:  None.
*
*  Returns:     None.
*
*  Rev. Date    By    Revision Notes
*  ----------   ---   ----------------
*  01/13/2003   JCM   Original Release
*
******************************************************************************
*/

void CIntelImgDlg::OnIntelimgApply()
{

    ReadControlValues();
    if( m_bChangesValid )
    {
        m_bApplied = TRUE;
        OnOK();
    }
}
// End OnIntelimgApply()

/*
******************************************************************************
*
*  Name:        CIntelImgDlg::OnAztecValues()
*
*  Description: Method called when button Aztec Demo Page Settings selected.
*               This loads fixed values based on the standard aztec intelligent
*               image demo sheet used by Charlotte with the 7400.
*
*  Parameters:  None.
*
*  Returns:     None.
*
*  Rev. Date    By    Revision Notes
*  ----------   ---   ----------------
*  01/13/2003   JCM   Original Release
*
******************************************************************************
*/

void CIntelImgDlg::OnAztecValues()
{
	m_uAspectRatio = INTELIMG_AZTEC_ASPECT_RATIO;
	m_uHeight = INTELIMG_AZTEC_HEIGHT;
	m_uWidth = INTELIMG_AZTEC_WIDTH;
	m_nOffsetX = INTELIMG_AZTEC_X_OFFSET;
	m_nOffsetY = INTELIMG_AZTEC_Y_OFFSET;
    UpdateData( FALSE );
    UpdateButtonStates();
}
// End OnAztecValues()

/*
******************************************************************************
*
*  Name:        CIntelImgDlg::OnCode39Values()
*
*  Description: Method called when button Code39 Demo Page Settings selected.
*               This loads fixed values based on the standard code39 intelligent
*               image demo sheet used by Skaneateles for IT4410.
*
*  Parameters:  None.
*
*  Returns:     None.
*
*  Rev. Date    By    Revision Notes
*  ----------   ---   ----------------
*  01/13/2003   JCM   Original Release
*
******************************************************************************
*/


void CIntelImgDlg::OnCode39Values()
{
	m_uAspectRatio = INTELIMG_C39_ASPECT_RATIO;
	m_uHeight = INTELIMG_C39_HEIGHT;
	m_uWidth = INTELIMG_C39_WIDTH;
	m_nOffsetX = INTELIMG_C39_X_OFFSET;
	m_nOffsetY = INTELIMG_C39_Y_OFFSET;
    UpdateData( FALSE );
    UpdateButtonStates();
}
// End OnCode39Values()

/*
******************************************************************************
*
*                           Private Methods
*
******************************************************************************
*/

/*
******************************************************************************
*
*  Name:        CIntelImgDlg::ReadControlValues()
*
*  Description: Copies the current control values to the member intelligent
*               imaging structure m_intelImg.
*
*  Parameters:  None.
*
*  Returns:     None.
*
*  Rev. Date    By    Revision Notes
*  ----------   ---   ----------------
*  01/13/2003   JCM   Original Release
*  03/06/2003   JCM   Added setting of m_bBinaryImage from new control.
*
******************************************************************************
*/

void CIntelImgDlg::ReadControlValues( void )
{
    // Make sure dialog is initialized before retrieving values.
    if( m_bInitialized )
    {
        // Get the current control values.
        if( (m_bChangesValid = UpdateData( TRUE )) > 0 )
        {
            // Save current values in structure.
            m_intelImg.dwAspectRatio = m_uAspectRatio;
            m_intelImg.dwHeight = m_uHeight;
            m_intelImg.dwWidth = m_uWidth;
            m_intelImg.nOffsetX = m_nOffsetX;
            m_intelImg.nOffsetY = m_nOffsetY;
            m_intelImg.bSendBinary = m_bBinaryImage;
        }
    }

    return;
}
// End ReadControlValues()

/*
******************************************************************************
*
*  Name:        CIntelImgDlg::ItemsChanged()
*
*  Description: Compares current control values with those currently in the
*               member intelligent imaging structure m_intelImg and returns
*               TRUE if any are different and FALSE otherwise.
*
*  Parameters:  None.
*
*  Returns:     TRUE  - If there are any mismatches.
*               FALSE - If member structure values and control values are same.
*
*  Rev. Date    By    Revision Notes
*  ----------   ---   ----------------
*  01/13/2003   JCM   Original Release
*  03/06/2003   JCM   Added m_bBinaryImage to controls list.
*
******************************************************************************
*/

BOOL CIntelImgDlg::ItemsChanged( void )
{
    BOOL    bChanged = FALSE;   // Return value.

    // Make sure dialog is initialized before retrieving values.
    if( m_bInitialized )
    {
        // Get the current control values.
        m_bChangesValid = UpdateData( TRUE );
        // If any values don't match, return TRUE.
        if( (m_intelImg.dwAspectRatio != m_uAspectRatio) ||
	        (m_intelImg.dwHeight != m_uHeight) ||
        	(m_intelImg.dwWidth != m_uWidth) ||
        	(m_intelImg.nOffsetX != m_nOffsetX) ||
    	    (m_intelImg.nOffsetY != m_nOffsetY) ||
            (m_intelImg.bSendBinary != m_bBinaryImage) )
        {
            bChanged = TRUE;
        }
    }
    return( bChanged );
}
// End ItemsChanged()

void CIntelImgDlg::UpdateButtonStates( void )
{
    GetDlgItem( IDC_INTELIMG_APPLY )->EnableWindow( ItemsChanged() );

    if( m_bInitialized )
    {
        // Are settings set for code 39?
        BOOL bEnabled = ((m_uAspectRatio != INTELIMG_C39_ASPECT_RATIO) ||
	                     (m_uHeight != INTELIMG_C39_HEIGHT) ||
                     	 (m_uWidth != INTELIMG_C39_WIDTH) ||
                     	 (m_nOffsetX != INTELIMG_C39_X_OFFSET) ||
                         (m_nOffsetY != INTELIMG_C39_Y_OFFSET)) ? TRUE : FALSE;
        // Enable/Disable Code39 button
        GetDlgItem( IDC_CODE39_VALUES )->EnableWindow( bEnabled );
        // Are settings set for Aztec?
        bEnabled = ((m_uAspectRatio != INTELIMG_AZTEC_ASPECT_RATIO) ||
	                (m_uHeight != INTELIMG_AZTEC_HEIGHT) ||
                  	(m_uWidth != INTELIMG_AZTEC_WIDTH) ||
                   	(m_nOffsetX != INTELIMG_AZTEC_X_OFFSET) ||
                    (m_nOffsetY != INTELIMG_AZTEC_Y_OFFSET)) ? TRUE : FALSE;
        // Enable/Disable Aztec button
        GetDlgItem( IDC_AZTEC_VALUES )->EnableWindow( bEnabled );
    }
}

//=================================================================
// $Log: IQ_Imaging_Sample_MFC/IQ_Imaging_Sample_MFC_Settings_Dlg.cpp  $
// Revision 1.2 2009/09/21 09:13:55EDT Haile, Adam Michael (E412723) 
//  
// Revision 1.1 2008/06/20 10:22:32EDT MontoroJ 
// Initial revision
// Member added to project d:/MKS_ES/ES/HHIDevSDK/HHI Imager SDK/Samples/IQ_Imaging_Sample_MFC/IQ_Imaging_Sample_MFC.pj
// Revision 1.2 2007/05/24 16:17:33EDT MontoroJ 
// - Rebranded to hhi from mat or hhp.
// Revision 1.2 2005/11/07 10:12:51EST MontoroJ 
// - Modified dialog behavior as follows:
//   - Apply button is only enabled if displayed items different from last apply (or values at
//     start)
//   - Aztec Demo and Code39 demo buttons are enabled as long as displayed items do not
//     match the values that would be set by that button.
// Revision 1.1 2003/06/19 11:54:17EDT holzhaud 
// Initial revision
// Member added to project d:/MKS_IT/SDK/Matrix_SDK_Examples/Matrix_SDK_Examples.pj
// Revision 1.6 2003/05/19 10:55:14EDT montoroj 
// - Fixed bug where it was possible to exit the dialog saving invalid data.
// Revision 1.5 2003/04/02 14:29:18EST montoroj 
// Modified InitDialog such that the dialogs are made to fill whole client area for HPC
// WinCE devices.
// Revision 1.4 2003/03/12 14:23:00EST montoroj 
// - Added code to support sending and setting of bits per pixel for intelligent image
//   transfer.
// Revision 1.3 2003/02/20 16:28:42EST montoroj 
// - Dumbo had put $LOG$ instead of $Log: IQ_Imaging_Sample_MFC/IQ_Imaging_Sample_MFC_Settings_Dlg.cpp  $
// - Dumbo had put Revision 1.2 2009/09/21 09:13:55EDT Haile, Adam Michael (E412723) 
// - Dumbo had put  
// - Dumbo had put Revision 1.1 2008/06/20 10:22:32EDT MontoroJ 
// - Dumbo had put Initial revision
// - Dumbo had put Member added to project d:/MKS_ES/ES/HHIDevSDK/HHI Imager SDK/Samples/IQ_Imaging_Sample_MFC/IQ_Imaging_Sample_MFC.pj
// - Dumbo had put Revision 1.2 2007/05/24 16:17:33EDT MontoroJ 
// - Dumbo had put - Rebranded to hhi from mat or hhp.
// - Dumbo had put Revision 1.2 2005/11/07 10:12:51EST MontoroJ 
// - Dumbo had put - Modified dialog behavior as follows:
// - Dumbo had put   - Apply button is only enabled if displayed items different from last apply (or values at
// - Dumbo had put     start)
// - Dumbo had put   - Aztec Demo and Code39 demo buttons are enabled as long as displayed items do not
// - Dumbo had put     match the values that would be set by that button.
// - Dumbo had put Revision 1.1 2003/06/19 11:54:17EDT holzhaud 
// - Dumbo had put Initial revision
// - Dumbo had put Member added to project d:/MKS_IT/SDK/Matrix_SDK_Examples/Matrix_SDK_Examples.pj
// - Dumbo had put Revision 1.6 2003/05/19 10:55:14EDT montoroj 
// - Dumbo had put - Fixed bug where it was possible to exit the dialog saving invalid data.
// - Dumbo had put Revision 1.5 2003/04/02 14:29:18EST montoroj 
// - Dumbo had put Modified InitDialog such that the dialogs are made to fill whole client area for HPC
// - Dumbo had put WinCE devices.
// - Dumbo had put Revision 1.4 2003/03/12 14:23:00EST montoroj 
// - Dumbo had put - Added code to support sending and setting of bits per pixel for intelligent image
// - Dumbo had put   transfer.
//=================================================================
